@@ -130,14 +130,15 @@
 
 // KDE Includes
 #include <KIO/Job>
+#include <KSharedConfig>
 
 // Qt Includes
 #include <QObject>
-#include <QNetworkReply>
 #include <QStringList>
 #include <QByteArray>
 
 // Forward Includes
+class QNetworkReply;
 class QNetworkRequest;
 class WebPage;
 
@@ -153,22 +154,34 @@ public:
     AdBlockManager(QObject *parent = 0);
     ~AdBlockManager();
 
+    bool isEnabled();
+    bool isHidingElements();
+
     QNetworkReply *block(const QNetworkRequest &request, WebPage *page);
     void applyHidingRules(WebPage *page);
-    void addSubscription(const QString &title, const QString &location);
 
-public Q_SLOTS:
-    void loadSettings(bool checkUpdateDate = true);
-    void showSettings();
+    void addCustomRule(const QString &, bool reloadPage = true);
+    void clearElementsLists();
 
 private:
-    void updateNextSubscription();
-    void saveRules(const QStringList &);
-    void loadRules(const QStringList &);
+    void updateSubscription(int);
+    bool subscriptionFileExists(int);
+
+    // load a file rule, given a path
+    void loadRules(const QString &rulesFilePath);
+
+    // load a single rule
+    void loadRuleString(const QString &stringRule);
 
 private Q_SLOTS:
-    void slotResult(KJob *);
-    void subscriptionData(KIO::Job*, const QByteArray&);
+    void loadSettings();
+    void showSettings();
+    void showBlockedItemDialog();
+
+    void slotFinished(KJob *);
+
+Q_SIGNALS:
+    void reloadCurrentPage();
 
 private:
     bool _isAdblockEnabled;
@@ -180,8 +193,10 @@ private:
     AdBlockRuleList _whiteList;
     QStringList _hideList;
 
-    int _index;
-    QByteArray _buffer;
+    QStringList _blockedElements;
+    int _hidedElements;
+
+    KSharedConfig::Ptr _adblockConfig;
 };
 
 #endif
