@@ -40,17 +40,18 @@
 #include "adblockmanager.h"
 #include "bookmarkmanager.h"
 #include "downloadmanager.h"
-#include "filterurljob.h"
 #include "historymanager.h"
 #include "iconmanager.h"
 #include "mainview.h"
 #include "mainwindow.h"
 #include "opensearchmanager.h"
+#include "searchengine.h"
 #include "sessionmanager.h"
 #include "syncmanager.h"
 #include "stackedurlbar.h"
 #include "tabbar.h"
 #include "urlbar.h"
+#include "urlresolver.h"
 #include "useragentmanager.h"
 #include "webtab.h"
 
@@ -67,10 +68,12 @@
 #include <KGlobal>
 #include <KCharsets>
 #include <KPushButton>
+#include <KMimeType>
 
 // Qt Includes
 #include <QVBoxLayout>
 #include <QDir>
+#include <QTimer>
 
 
 using namespace ThreadWeaver;
@@ -80,9 +83,6 @@ Application::Application()
     : KUniqueApplication()
     , _privateBrowsingAction(0)
 {
-    connect(Weaver::instance(), SIGNAL(jobDone(ThreadWeaver::Job*)),
-            this, SLOT(loadResolvedUrl(ThreadWeaver::Job*)));
-
     _privateBrowsingAction = new KAction(KIcon("view-media-artist"), i18n("Private &Browsing"), this);
     _privateBrowsingAction->setCheckable(true);
     connect(_privateBrowsingAction, SIGNAL(triggered(bool)), this, SLOT(setPrivateBrowsingMode(bool)));
@@ -186,138 +186,145 @@ int Application::newInstance()
     // so, we have 8 possible cases...
     static bool isFirstLoad = true;
     bool areThereArguments = (args->count() > 0);
-    bool isRekonqCrashed = (ReKonfig::recoverOnCrash() > 0);
-    // note that isRekonqCrashed is always true if it is not the first load
-    // !isFirstLoad -> isRekonqCrashed
+    bool hasToBeRecovered = (ReKonfig::recoverOnCrash() > 0);
+    // note that hasToBeRecovered is always true if it is not the first load
+    // !isFirstLoad -> hasToBeRecovered
 
     kDebug() << "is first load? " << isFirstLoad;
     kDebug() << "are there arguments? " << areThereArguments;
-    kDebug() << "is rekonq crashed? " << isRekonqCrashed;
+    kDebug() << "is rekonq crashed? " << hasToBeRecovered;
 
-    int exitValue = 1 * isFirstLoad + 2 * areThereArguments + 4 * isRekonqCrashed;
 
-    if (isFirstLoad && isSessionRestored())
+    if (!isSessionRestored())
     {
-        isFirstLoad = false;
-
-        return exitValue;
-    }
-
-    if (isRekonqCrashed && isFirstLoad)
-    {
-        loadUrl(KUrl("about:closedTabs"), Rekonq::NewWindow);
-        QTimer::singleShot(1000, mainWindow()->currentTab(), SLOT(showMessageBar()));
-    }
-
-    if (areThereArguments)
-    {
-        // prepare URLS to load
-        KUrl::List urlList;
-        for (int i = 0; i < args->count(); ++i)
+        if (areThereArguments)
         {
-            const KUrl u = args->url(i);
+            // prepare URLS to load
+            KUrl::List urlList;
+            for (int i = 0; i < args->count(); ++i)
+            {
+                const KUrl u = args->url(i);
 
-            if (u.isLocalFile() && QFile::exists(u.toLocalFile())) // "rekonq somefile.html" case
-                urlList += u;
+                if (u.isLocalFile() && QFile::exists(u.toLocalFile())) // "rekonq somefile.html" case
+                    urlList += u;
+                else
+                {
+                    // "rekonq kde.org" || "rekonq kde:kdialog" case
+                    UrlResolver res(args->arg(i));
+                    UrlSearchList list = res.orderedSearchItems();
+                    if (list.isEmpty())
+                    {
+                        urlList += u;
+                    }
+                    else
+                    {
+                        urlList += list.first().url;
+                    }
+                }
+            }
+
+            if (isFirstLoad && (ReKonfig::startupBehaviour() == 2) && sessionManager()->restoreSessionFromScratch())
+            {
+                isFirstLoad = false;
+            }
+
+            // first argument: 99% of the time we have just that...
+            if (isFirstLoad)
+            {
+                // No windows in the current desktop? No windows at all?
+                // Create a new one and load there sites...
+                loadUrl(urlList.at(0), Rekonq::NewWindow);
+            }
             else
             {
-                // "rekonq kde.org" || "rekonq kde:kdialog" case
-                UrlResolver res(args->arg(i));
-                UrlSearchList list = res.orderedSearchItems();
-                if (list.isEmpty())
+                if (!ReKonfig::openExternalLinksInNewWindow())
                 {
-                    urlList += u;
+                    loadUrl(urlList.at(0), Rekonq::NewFocusedTab);
                 }
                 else
                 {
-                    urlList += list.first().url;
+                    loadUrl(urlList.at(0), Rekonq::NewWindow);
                 }
-            }
-        }
 
-        // first argument: 99% of the time we have just that...
-        if (isFirstLoad)
-        {
-            // No windows in the current desktop? No windows at all?
-            // Create a new one and load there sites...
-            loadUrl(urlList.at(0), Rekonq::NewWindow);
-        }
-        else
-        {
+                if (!mainWindow()->isActiveWindow())
+                    KWindowSystem::demandAttention(mainWindow()->winId(), true);
+            }
+
+            // following arguments: what's best behavior here?
+            // I'm pretty sure no one has real opinion about...
             if (!ReKonfig::openExternalLinksInNewWindow())
             {
-                loadUrl(urlList.at(0), Rekonq::NewFocusedTab);
+                for (int i = 1; i < urlList.count(); ++i)
+                    loadUrl(urlList.at(i), Rekonq::NewFocusedTab);
             }
             else
             {
-                loadUrl(urlList.at(0), Rekonq::NewWindow);
+                for (int i = 1; i < urlList.count(); ++i)
+                    loadUrl(urlList.at(i), Rekonq::NewWindow);
             }
-
-            if (!mainWindow()->isActiveWindow())
-                KWindowSystem::demandAttention(mainWindow()->winId(), true);
-        }
-
-        // following arguments: what's best behavior here? I'm pretty sure no one has real opinion here
-        if (!ReKonfig::openExternalLinksInNewWindow())
-        {
-            for (int i = 1; i < urlList.count(); ++i)
-                loadUrl(urlList.at(i), Rekonq::NewFocusedTab);
         }
         else
         {
-            for (int i = 1; i < urlList.count(); ++i)
-                loadUrl(urlList.at(i), Rekonq::NewWindow);
-        }
-    }
-    else
-    {
-        // we are starting rekonq, for the first time with no args: use startup behaviour
-        if (isFirstLoad && !isRekonqCrashed)
-        {
-            switch (ReKonfig::startupBehaviour())
+            if (isFirstLoad)
             {
-            case 0: // open home page
-                newMainWindow()->homePage();
-                break;
-            case 1: // open new tab page
-                loadUrl(KUrl("about:home"), Rekonq::NewWindow);
-                break;
-            case 2: // restore session
-                if (sessionManager()->restoreSessionFromScratch())
+                if (hasToBeRecovered)
                 {
+                    loadUrl(KUrl("about:closedTabs"), Rekonq::NewWindow);
+                }
+                else
+                {
+                    switch (ReKonfig::startupBehaviour())
+                    {
+                    case 0: // open home page
+                        newMainWindow()->homePage();
+                        break;
+                    case 1: // open new tab page
+                        loadUrl(KUrl("about:home"), Rekonq::NewWindow);
+                        break;
+                    case 2: // restore session
+                        if (sessionManager()->restoreSessionFromScratch())
+                        {
+                            break;
+                        }
+                    default:
+                        newMainWindow()->homePage();
+                        break;
+                    }
+                }
+            }
+            else
+            {
+                switch (ReKonfig::newTabsBehaviour())
+                {
+                case 0: // new tab page
+                    loadUrl(KUrl("about:home") , Rekonq::NewWindow);
+                    break;
+                case 2: // homepage
+                    loadUrl(KUrl(ReKonfig::homePage()) , Rekonq::NewWindow);
+                    break;
+                case 1: // blank page
+                default:
+                    loadUrl(KUrl("about:blank") , Rekonq::NewWindow);
                     break;
                 }
-            default:
-                newMainWindow()->homePage();
-                break;
             }
         }
-        else if (!isFirstLoad)   // rekonq has just been started. Just open a new window
-        {
-            switch (ReKonfig::newTabsBehaviour())
-            {
-            case 0: // new tab page
-                loadUrl(KUrl("about:home") , Rekonq::NewWindow);
-                break;
-            case 2: // homepage
-                loadUrl(KUrl(ReKonfig::homePage()) , Rekonq::NewWindow);
-                break;
-            case 1: // blank page
-            default:
-                loadUrl(KUrl("about:blank") , Rekonq::NewWindow);
-                break;
-            }
-
-        }
-    }
-
-    if (!isRekonqCrashed)
-    {
-        sessionManager()->setSessionManagementEnabled(true);
     }
 
     if (isFirstLoad)
     {
+        if (hasToBeRecovered)
+        {
+            QTimer::singleShot(1000, mainWindow()->currentTab(), SLOT(showMessageBar()));
+        }
+        else
+        {
+            sessionManager()->setSessionManagementEnabled(true);
+        }
+
+        if (ReKonfig::checkDefaultSearchEngine() && !hasToBeRecovered && SearchEngine::defaultEngine().isNull())
+            QTimer::singleShot(2000, mainWindow()->currentTab(), SLOT(showSearchEngineBar()));
+
         // updating rekonq configuration
         updateConfiguration();
 
@@ -325,10 +332,6 @@ int Application::newInstance()
 
         historyManager();
 
-        // bookmarks loading
-        connect(bookmarkManager(), SIGNAL(openUrl(KUrl,Rekonq::OpenType)),
-                instance(), SLOT(loadUrl(KUrl,Rekonq::OpenType)));
-
         ReKonfig::setRecoverOnCrash(ReKonfig::recoverOnCrash() + 1);
         saveConfiguration();
     }
@@ -336,7 +339,7 @@ int Application::newInstance()
     KStartupInfo::appStarted();
     isFirstLoad = false;
 
-    return exitValue;
+    return 0;
 }
 
 
@@ -468,56 +471,23 @@ void Application::loadUrl(const KUrl& url, const Rekonq::OpenType& type)
     if (url.url().contains("about:") && url.url().contains("/"))
         newType = Rekonq::CurrentTab;
 
-    // first, create the webview(s) to not let hangs UI..
-    WebTab *tab = 0;
     MainWindow *w = 0;
-    w = (newType == Rekonq::NewWindow)
-        ? newMainWindow()
-        : mainWindow();
+    if (newType == Rekonq::NewWindow
+            || (newType == Rekonq::NewTab && ReKonfig::openLinksInNewWindow()))
+    {
+        w = newMainWindow();
+        newType = Rekonq::CurrentTab;
+    }
+    else
+    {
+        w = mainWindow();
+    }
 
     // be SURE window exists
     if (!w)
         w = newMainWindow();
 
-    switch (newType)
-    {
-    case Rekonq::NewTab:
-        if (ReKonfig::openLinksInNewWindow())
-        {
-            w = newMainWindow();
-            tab = w->mainView()->currentWebTab();
-        }
-        else
-        {
-            tab = w->mainView()->newWebTab(!ReKonfig::openNewTabsInBackground());
-        }
-        break;
-    case Rekonq::NewFocusedTab:
-        tab = w->mainView()->newWebTab(true);
-        break;
-    case Rekonq::NewBackTab:
-        tab = w->mainView()->newWebTab(false);
-        break;
-    case Rekonq::NewWindow:
-    case Rekonq::CurrentTab:
-        tab = w->mainView()->currentWebTab();
-        break;
-    };
-
-
-    // rapidly show first loading url..
-    int tabIndex = w->mainView()->indexOf(tab);
-    Q_ASSERT(tabIndex != -1);
-    UrlBar *barForTab = qobject_cast<UrlBar *>(w->mainView()->widgetBar()->widget(tabIndex));
-    barForTab->activateSuggestions(false);
-    barForTab->setQUrl(url);
-
-    WebView *view = tab->view();
-    if (view)
-    {
-        FilterUrlJob *job = new FilterUrlJob(view, url.pathOrUrl(), this);
-        Weaver::instance()->enqueue(job);
-    }
+    w->loadCheckedUrl(url, newType);
 }
 
 
@@ -541,6 +511,10 @@ void Application::removeMainWindow(MainWindow *window)
 {
     m_mainWindows.removeOne(window);
     kDebug() << "Removing Window from app window list...";
+
+    // bye bye...
+    if (m_mainWindows.count() == 0)
+        quit();
 }
 
 
@@ -560,22 +534,6 @@ AdBlockManager *Application::adblockManager()
 }
 
 
-void Application::loadResolvedUrl(ThreadWeaver::Job *job)
-{
-    FilterUrlJob *threadedJob = static_cast<FilterUrlJob *>(job);
-    KUrl url = threadedJob->url();
-    WebView *view = threadedJob->view();
-
-    if (view)
-    {
-        view->load(url);
-    }
-
-    // Bye and thanks :)
-    delete threadedJob;
-}
-
-
 void Application::newWindow()
 {
     loadUrl(KUrl("about:home"), Rekonq::NewWindow);
@@ -729,7 +687,7 @@ void Application::updateConfiguration()
         break;
 
     default: // non extant case
-        ASSERT_NOT_REACHED();
+        ASSERT_NOT_REACHED(unknown hoveringTabOption);
         break;
     }
 
@@ -847,6 +805,7 @@ void Application::createWebAppShortcut()
     dialog->setCaption(i18nc("@title:window", "Create Application Shortcut"));
     dialog->setButtons(KDialog::Ok | KDialog::Cancel);
     dialog->button(KDialog::Ok)->setText(i18n("Create"));
+    dialog->setMinimumSize(400, 50);
 
     Ui::webAppCreation wAppWidget;
     QWidget widget;
@@ -875,13 +834,13 @@ void Application::createWebAppShortcut()
                                  + QL1S("Icon=") + iconPath + QL1S("\n")
                                  + QL1S("Exec=kwebapp ") + u.url() + QL1S("\n")
                                  + QL1S("Type=Application\n")
-                                 + QL1S("Categories=Application;Network;WebBrowser\n")
+                                 + QL1S("Categories=Application;Network\n")
                                  ;
 
         if (ReKonfig::createDesktopAppShortcut())
         {
             QString desktop = KGlobalSettings::desktopPath();
-            QFile wAppFile(desktop + QL1C('/') + title + QL1S(".desktop"));
+            QFile wAppFile(desktop + QL1C('/') + title);
 
             if (!wAppFile.open(QIODevice::WriteOnly | QIODevice::Text))
             {
@@ -893,6 +852,7 @@ void Application::createWebAppShortcut()
             out.setCodec("UTF-8");
             out << shortcutString;
 
+            wAppFile.setPermissions(QFile::ReadUser | QFile::WriteUser | QFile::ExeUser | QFile::ReadGroup | QFile::ReadOther);
             wAppFile.close();
         }
 
