@@ -44,7 +44,19 @@
 #include <KMessageBox>
 
 // Qt Includes
-#include <QtGui/QClipboard>
+#include <QClipboard>
+
+// Nepomuk config include
+#include "config-nepomuk.h"
+
+#ifdef HAVE_NEPOMUK
+// Local Nepomuk Includes
+#include "resourcelinkdialog.h"
+
+// Nepomuk Includes
+#include <Nepomuk/Resource>
+#include <Nepomuk/Vocabulary/NFO>
+#endif
 
 
 BookmarkOwner::BookmarkOwner(KBookmarkManager *manager, QObject *parent)
@@ -86,6 +98,11 @@ KAction* BookmarkOwner::createAction(const KBookmark &bookmark, const BookmarkAc
     case EDIT:
         return createAction(i18n("Edit"), "configure",
                             i18n("Edit the bookmark"), SLOT(editBookmark(KBookmark)), bookmark);
+#ifdef HAVE_NEPOMUK
+    case FANCYBOOKMARK:
+        return createAction(i18n("Fancy Bookmark"), "nepomuk",
+                            i18n("Link Nepomuk resources"), SLOT(fancyBookmark(KBookmark)), bookmark);
+#endif
     case DELETE:
         return  createAction(i18n("Delete"), "edit-delete",
                              i18n("Delete the bookmark"), SLOT(deleteBookmark(KBookmark)), bookmark);
@@ -96,7 +113,7 @@ KAction* BookmarkOwner::createAction(const KBookmark &bookmark, const BookmarkAc
         return  createAction(i18n("Unset this folder as the toolbar folder"), "bookmark-toolbar",
                              "", SLOT(unsetToolBarFolder()), bookmark);
     default:
-        ASSERT_NOT_REACHED();
+        ASSERT_NOT_REACHED(unknown BookmarkAction);
         return 0;
     }
 }
@@ -205,6 +222,12 @@ KBookmark BookmarkOwner::bookmarkCurrentPage(const KBookmark &bookmark)
     else
     {
         parent = rApp->bookmarkManager()->rootGroup();
+#ifdef HAVE_NEPOMUK
+        Nepomuk::Resource nfoResource;
+        nfoResource = ((QUrl)currentUrl());
+        nfoResource.addType(Nepomuk::Vocabulary::NFO::Website());
+        nfoResource.setLabel(currentTitle());
+#endif
     }
 
     KBookmark newBk = parent.addBookmark(currentTitle(), KUrl(currentUrl()));
@@ -298,6 +321,16 @@ void BookmarkOwner::editBookmark(KBookmark bookmark)
 }
 
 
+#ifdef HAVE_NEPOMUK
+void BookmarkOwner::fancyBookmark(KBookmark bookmark)
+{
+    Nepomuk::Resource nfoResource = (KUrl)bookmark.url();
+    Nepomuk::ResourceLinkDialog r(nfoResource);
+    r.exec();
+
+}
+#endif
+
 bool BookmarkOwner::deleteBookmark(const KBookmark &bookmark)
 {
     if (bookmark.isNull())
@@ -334,6 +367,10 @@ bool BookmarkOwner::deleteBookmark(const KBookmark &bookmark)
         return false;
 
     bmg.deleteBookmark(bookmark);
+#ifdef HAVE_NEPOMUK
+    Nepomuk::Resource nfoResource(bookmark.url());
+    nfoResource.remove();
+#endif
     m_manager->emitChanged(bmg);
     return true;
 }
