@@ -164,7 +164,7 @@ BookmarkToolBar::BookmarkToolBar(KToolBar *toolBar, QObject *parent)
 {
     toolBar->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(toolBar, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenu(QPoint)));
-    connect(rApp->bookmarkManager()->manager(), SIGNAL(changed(QString,QString)), this, SLOT(hideMenu()));
+    connect(rApp->bookmarkManager()->manager(), SIGNAL(changed(QString, QString)), this, SLOT(hideMenu()));
     toolBar->setAcceptDrops(true);
     toolBar->installEventFilter(this);
     toolBar->setShortcutEnabled(false);
@@ -289,9 +289,9 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     case QEvent::DragEnter:
     {
         QDragEnterEvent *dragEvent = static_cast<QDragEnterEvent*>(event);
-        if (dragEvent->mimeData()->hasFormat("application/rekonq-bookmark")
-            || dragEvent->mimeData()->hasFormat("text/uri-list")
-            || dragEvent->mimeData()->hasFormat("text/plain"))
+        if (dragEvent->mimeData()->hasFormat(BookmarkManager::bookmark_mime_type())
+                || dragEvent->mimeData()->hasFormat("text/uri-list")
+                || dragEvent->mimeData()->hasFormat("text/plain"))
         {
             QFrame* dropIndicatorWidget = new QFrame(toolBar());
             dropIndicatorWidget->setFrameShape(QFrame::VLine);
@@ -321,9 +321,9 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     case QEvent::DragMove:
     {
         QDragMoveEvent *dragEvent = static_cast<QDragMoveEvent*>(event);
-        if (dragEvent->mimeData()->hasFormat("application/rekonq-bookmark")
-            || dragEvent->mimeData()->hasFormat("text/uri-list")
-            || dragEvent->mimeData()->hasFormat("text/plain"))
+        if (dragEvent->mimeData()->hasFormat(BookmarkManager::bookmark_mime_type())
+                || dragEvent->mimeData()->hasFormat("text/uri-list")
+                || dragEvent->mimeData()->hasFormat("text/plain"))
         {
             QAction *overAction = toolBar()->actionAt(dragEvent->pos());
             KBookmarkActionInterface *overActionBK = dynamic_cast<KBookmarkActionInterface*>(overAction);
@@ -400,9 +400,9 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
             m_checkedAction->setChecked(false);
         }
 
-        if (dropEvent->mimeData()->hasFormat("application/rekonq-bookmark"))
+        if (dropEvent->mimeData()->hasFormat(BookmarkManager::bookmark_mime_type()))
         {
-            QByteArray addresses = dropEvent->mimeData()->data("application/rekonq-bookmark");
+            QByteArray addresses = dropEvent->mimeData()->data(BookmarkManager::bookmark_mime_type());
             bookmark =  rApp->bookmarkManager()->findByAddress(QString::fromLatin1(addresses.data()));
             if (bookmark.isNull())
                 return false;
@@ -589,7 +589,7 @@ void BookmarkToolBar::startDrag()
         KBookmark bookmark = action->bookmark();
 
         QByteArray address = bookmark.address().toLatin1();
-        mimeData->setData("application/rekonq-bookmark", address);
+        mimeData->setData(BookmarkManager::bookmark_mime_type(), address);
         bookmark.populateMimeData(mimeData);
 
         QDrag *drag = new QDrag(toolBar());
