@@ -37,6 +37,7 @@
 
 // KDE Includes
 #include <kio/accessmanager.h>
+#include <KIO/CopyJob>
 
 // Qt Includes
 #include <QObject>
@@ -53,6 +54,7 @@ class REKONQ_TESTS_EXPORT DownloadManager : public QObject
 
 public:
     DownloadManager(QObject *parent = 0);
+    ~DownloadManager();
 
     DownloadList downloads() const
     {
@@ -66,15 +68,22 @@ public:
 
     void downloadLinksWithKGet(const QVariant &contentList);
 
+    void removeDownloadItem(int index);
+
+private:
+    void init();
+
+    DownloadItem* addDownload(KIO::CopyJob *job);
+    DownloadItem* addKGetDownload(const QString &srcUrl, const QString &destUrl);
+
 Q_SIGNALS:
     void newDownloadAdded(QObject *item);
     void notifyDownload(const QString&, Rekonq::Notify = Rekonq::Download);
 
 private:
-    void init();
-    DownloadItem* addDownload(const QString &srcUrl, const QString &destUrl);
-
     DownloadList m_downloadList;
+
+    bool m_needToSave;
 };
 
 #endif // DOWNLOADMANAGER_H
