@@ -30,10 +30,10 @@
 #include "autosaver.moc"
 
 // Qt Includes
-#include <QtCore/QMetaObject>
-#include <QtCore/QTimerEvent>
-#include <QtCore/QBasicTimer>
-#include <QtCore/QTime>
+#include <QMetaObject>
+#include <QTimerEvent>
+#include <QBasicTimer>
+#include <QTime>
 
 
 const int AUTOSAVE_TIME  = 1000 * 3;  // seconds
