@@ -33,9 +33,6 @@
 // Rekonq Includes
 #include "rekonq_defines.h"
 
-// Local Includes
-#include "urlresolver.h"
-
 // KDE Includes
 #include <KUrl>
 
@@ -43,13 +40,18 @@
 #include <QDateTime>
 #include <QHash>
 #include <QObject>
-#include <QTimer>
-#include <QSortFilterProxyModel>
-#include <QWebHistoryInterface>
 #include <QWebHistory>
 
 #include <math.h>
 
+// Forward Declarations
+class AutoSaver;
+class HistoryFilterModel;
+class HistoryTreeModel;
+
+class QWebHistory;
+
+
 /**
  * Elements in this class represent an history item
  *
@@ -100,6 +102,7 @@ public:
 
 // ---------------------------------------------------------------------------------------------------------------
 
+
 class TabHistory
 {
 public:
@@ -133,20 +136,16 @@ public:
     QByteArray history;
 };
 
+
 // ---------------------------------------------------------------------------------------------------------------
 
 
-// Forward Declarations
-class AutoSaver;
-class HistoryFilterModel;
-class HistoryTreeModel;
-
 /**
  * THE History Manager:
  * It manages rekonq history
  *
  */
-class REKONQ_TESTS_EXPORT HistoryManager : public QWebHistoryInterface
+class REKONQ_TESTS_EXPORT HistoryManager : public QObject
 {
     Q_OBJECT
 
@@ -155,8 +154,7 @@ public:
     ~HistoryManager();
 
     bool historyContains(const QString &url) const;
-    void addHistoryEntry(const QString &url);
-    void updateHistoryEntry(const KUrl &url, const QString &title);
+    void addHistoryEntry(const KUrl &url, const QString &title);
     void removeHistoryEntry(const KUrl &url, const QString &title = QString());
 
     QList<HistoryItem> find(const QString &text);
@@ -181,7 +179,6 @@ Q_SIGNALS:
     void historyReset();
     void entryAdded(const HistoryItem &item);
     void entryRemoved(const HistoryItem &item);
-    void entryUpdated(int offset);
 
     void historySaved();
 
