@@ -35,6 +35,7 @@
 
 // Local Includes
 #include "application.h"
+#include "historymanager.h"
 #include "iconmanager.h"
 
 // KDE Includes
@@ -43,17 +44,17 @@
 #include <KIcon>
 
 // Qt Includes
-#include <QtCore/QList>
-#include <QtCore/QUrl>
-#include <QtCore/QDate>
-#include <QtCore/QDateTime>
-#include <QtCore/QString>
-#include <QtCore/QFile>
-#include <QtCore/QDataStream>
-#include <QtCore/QBuffer>
-#include <QFileInfo>
+#include <QList>
+#include <QUrl>
+#include <QDate>
+#include <QDateTime>
+#include <QString>
+#include <QFile>
+#include <QDataStream>
+#include <QBuffer>
 
-#include <QtGui/QClipboard>
+#include <QClipboard>
+#include <QFileInfo>
 
 // generic algorithms
 #include <QtAlgorithms>
@@ -67,7 +68,6 @@ HistoryModel::HistoryModel(HistoryManager *history, QObject *parent)
     connect(m_historyManager, SIGNAL(historyReset()), this, SLOT(historyReset()));
     connect(m_historyManager, SIGNAL(entryRemoved(HistoryItem)), this, SLOT(historyReset()));
     connect(m_historyManager, SIGNAL(entryAdded(HistoryItem)), this, SLOT(entryAdded()));
-    connect(m_historyManager, SIGNAL(entryUpdated(int)), this, SLOT(entryUpdated(int)));
 }
 
 
@@ -84,13 +84,6 @@ void HistoryModel::entryAdded()
 }
 
 
-void HistoryModel::entryUpdated(int offset)
-{
-    QModelIndex idx = index(offset, 0);
-    emit dataChanged(idx, idx);
-}
-
-
 QVariant HistoryModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (orientation == Qt::Horizontal
@@ -231,12 +224,12 @@ void HistoryFilterModel::setSourceModel(QAbstractItemModel *newSourceModel)
     if (sourceModel())
     {
         disconnect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
-        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                   this, SLOT(dataChanged(QModelIndex,QModelIndex)));
-        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                   this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
-        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                   this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)),
+                   this, SLOT(dataChanged(QModelIndex, QModelIndex)));
+        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
+                   this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
+        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
+                   this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
     }
 
     QAbstractProxyModel::setSourceModel(newSourceModel);
@@ -245,12 +238,12 @@ void HistoryFilterModel::setSourceModel(QAbstractItemModel *newSourceModel)
     {
         m_loaded = false;
         connect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
-        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
-        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
-        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)),
+                this, SLOT(sourceDataChanged(QModelIndex, QModelIndex)));
+        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
+                this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
+        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
+                this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
     }
 }
 
@@ -412,16 +405,16 @@ bool HistoryFilterModel::removeRows(int row, int count, const QModelIndex &paren
     if (row < 0 || count <= 0 || row + count > rowCount(parent) || parent.isValid())
         return false;
     int lastRow = row + count - 1;
-    disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-               this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+    disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
+               this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
     beginRemoveRows(parent, row, lastRow);
     int oldCount = rowCount();
     int start = sourceModel()->rowCount() - m_sourceRow.value(row);
     int end = sourceModel()->rowCount() - m_sourceRow.value(lastRow);
     sourceModel()->removeRows(start, end - start + 1);
     endRemoveRows();
-    connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+    connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
+            this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
     m_loaded = false;
     if (oldCount - count != rowCount())
         reset();
@@ -632,10 +625,10 @@ void HistoryTreeModel::setSourceModel(QAbstractItemModel *newSourceModel)
     {
         disconnect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
         disconnect(sourceModel(), SIGNAL(layoutChanged()), this, SLOT(sourceReset()));
-        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                   this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
-        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                   this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
+                   this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
+        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
+                   this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
     }
 
     QAbstractProxyModel::setSourceModel(newSourceModel);
@@ -644,10 +637,10 @@ void HistoryTreeModel::setSourceModel(QAbstractItemModel *newSourceModel)
     {
         connect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
         connect(sourceModel(), SIGNAL(layoutChanged()), this, SLOT(sourceReset()));
-        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
-        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)),
+                this, SLOT(sourceRowsInserted(QModelIndex, int, int)));
+        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)),
+                this, SLOT(sourceRowsRemoved(QModelIndex, int, int)));
     }
 
     reset();
