@@ -36,6 +36,7 @@
 
 // Local Includes
 #include "application.h"
+#include "historymanager.h"
 #include "iconmanager.h"
 #include "mainwindow.h"
 #include "sessionmanager.h"
@@ -87,7 +88,7 @@ MainView::MainView(QWidget *parent)
     connect(tabBar, SIGNAL(detachTab(int)),         this,   SLOT(detachTab(int)));
 
     connect(tabBar, SIGNAL(tabCloseRequested(int)), this,   SLOT(closeTab(int)));
-    connect(tabBar, SIGNAL(tabMoved(int,int)),     m_widgetBar, SLOT(moveBar(int,int)));
+    connect(tabBar, SIGNAL(tabMoved(int, int)),     m_widgetBar, SLOT(moveBar(int, int)));
 
     // current page index changing
     connect(this, SIGNAL(currentChanged(int)), this, SLOT(currentChanged(int)));
@@ -104,6 +105,16 @@ MainView::MainView(QWidget *parent)
 }
 
 
+MainView::~MainView()
+{
+    // NOTE
+    // we wanna delete m_widgetBar later to get sure
+    // all its children (i.e. the urlbars) got deleted in
+    // WebTab dtor.
+    m_widgetBar->deleteLater();
+}
+
+
 void MainView::addNewTabButton(QAction *newTabAction)
 {
     m_addTabButton->setDefaultAction(newTabAction);
@@ -138,6 +149,12 @@ WebTab *MainView::currentWebTab() const
 }
 
 
+QList<TabHistory> MainView::recentlyClosedTabs()
+{
+    return m_recentlyClosedTabs;
+}
+
+
 void MainView::updateTabBar()
 {
     if (ReKonfig::alwaysShowTabBar() || count() > 1)
@@ -248,13 +265,13 @@ void MainView::currentChanged(int index)
         // disconnecting webpage from mainview
         disconnect(oldTab->page(), SIGNAL(statusBarMessage(QString)),
                    this, SIGNAL(showStatusBarMessage(QString)));
-        disconnect(oldTab->page(), SIGNAL(linkHovered(QString,QString,QString)),
+        disconnect(oldTab->page(), SIGNAL(linkHovered(QString, QString, QString)),
                    this, SIGNAL(linkHovered(QString)));
     }
 
     connect(tab->page(), SIGNAL(statusBarMessage(QString)),
             this, SIGNAL(showStatusBarMessage(QString)));
-    connect(tab->page(), SIGNAL(linkHovered(QString,QString,QString)),
+    connect(tab->page(), SIGNAL(linkHovered(QString, QString, QString)),
             this, SIGNAL(linkHovered(QString)));
 
     emit currentTitle(tab->view()->title());
@@ -414,8 +431,9 @@ void MainView::cloneTab(int index)
         return;
 
     KUrl url = webTab(index)->url();
+    QWebHistory* history = webTab(index)->view()->history();
 
-    rApp->loadUrl(url, Rekonq::NewTab);
+    rApp->mainWindow()->loadUrl(url, Rekonq::NewTab, history);
 }
 
 
@@ -442,17 +460,15 @@ void MainView::closeTab(int index, bool del)
             return;
     }
 
-    kDebug() << "URL: " << tabToClose->url();
-    kDebug() << "rekonq page: " << tabToClose->page()->isOnRekonqPage();
-
     if (!tabToClose->url().isEmpty()
             && tabToClose->url().scheme() != QL1S("about")
-            && !tabToClose->page()->isOnRekonqPage()
             && !QWebSettings::globalSettings()->testAttribute(QWebSettings::PrivateBrowsingEnabled)
        )
     {
         const int recentlyClosedTabsLimit = 8;
         TabHistory history(tabToClose->view()->history());
+        history.title = tabToClose->view()->title();
+        history.url = tabToClose->url().url();
 
         m_recentlyClosedTabs.removeAll(history);
         if (m_recentlyClosedTabs.count() == recentlyClosedTabsLimit)
@@ -500,7 +516,7 @@ void MainView::closeTab(int index, bool del)
 
     if (del)
     {
-        delete tabToClose;
+        tabToClose->deleteLater();
     }
 }
 
@@ -614,7 +630,6 @@ void MainView::webViewTitleChanged(const QString &title)
             tabBar()->setTabHighlighted(index);
     }
 
-    rApp->historyManager()->updateHistoryEntry(tab->url(), tabTitle);
     if (ReKonfig::hoveringTabOption() == 1)
         tabBar()->setTabToolTip(index, tabTitle.remove('&'));
 }
@@ -626,11 +641,16 @@ void MainView::webViewUrlChanged(const QUrl &url)
     if (!view)
         return;
 
-    int index = indexOf(view->parentWidget());
+    WebTab *tab = qobject_cast<WebTab *>(view->parentWidget());
+    if (!tab)
+        return;
+
+    int index = indexOf(tab);
     if (ReKonfig::hoveringTabOption() == 2)
         tabBar()->setTabToolTip(index, url.toString());
-    
-    rApp->mainWindow()->updateHistoryActions();
+
+    if (tab == rApp->mainWindow()->currentTab())
+        rApp->mainWindow()->updateHistoryActions();
 }
 
 
@@ -677,6 +697,7 @@ void MainView::restoreClosedTab(int i, bool inNewTab)
                     ;
 
     history.applyHistory(view->history());
+    view->load(KUrl(history.url));
 
     // just to get sure...
     m_recentlyClosedTabs.removeAll(history);
