@@ -33,15 +33,13 @@
 
 // Rekonq Includes
 #include "rekonq_defines.h"
-
-// Local Includes
 #include "historymanager.h"
 
 // KDE Includes
 #include <KTabWidget>
 
 // Forward Declarations
-class HistoryItem;
+class MainWindow;
 class StackedUrlBar;
 class TabBar;
 class UrlBar;
@@ -65,6 +63,7 @@ class REKONQ_TESTS_EXPORT MainView : public KTabWidget
 
 public:
     MainView(QWidget *parent);
+    ~MainView();
 
     inline StackedUrlBar *widgetBar() const
     {
@@ -101,10 +100,7 @@ public:
      */
     WebTab *newWebTab(bool focused = true);
 
-    inline QList<TabHistory> recentlyClosedTabs()
-    {
-        return m_recentlyClosedTabs;
-    }
+    QList<TabHistory> recentlyClosedTabs();
 
     void restoreClosedTab(int i, bool inNewTab = true);
 
