@@ -43,6 +43,7 @@
 #include "bookmarkstoolbar.h"
 #include "downloadmanager.h"
 #include "findbar.h"
+#include "historymanager.h"
 #include "historypanel.h"
 #include "iconmanager.h"
 #include "mainview.h"
@@ -124,6 +125,7 @@ MainWindow::MainWindow()
 {
     // Setting attributes (just to be sure...)
     setAttribute(Qt::WA_DeleteOnClose, true);
+    setAttribute(Qt::WA_QuitOnClose, true);
 
     // creating a centralWidget containing panel, m_view and the hidden findbar
     QWidget *centralWidget = new QWidget;
@@ -172,7 +174,7 @@ MainWindow::MainWindow()
     setStatusBar(0);
 
     // setting popup notification
-    connect(rApp, SIGNAL(focusChanged(QWidget*,QWidget*)), m_popup, SLOT(hide()));
+    connect(rApp, SIGNAL(focusChanged(QWidget*, QWidget*)), m_popup, SLOT(hide()));
     m_popup->setAutoFillBackground(true);
     m_popup->setMargin(4);
     m_popup->raise();
@@ -180,10 +182,10 @@ MainWindow::MainWindow()
     connect(m_hidePopupTimer, SIGNAL(timeout()), m_popup, SLOT(hide()));
 
     // notification system
-    connect(m_view, SIGNAL(showStatusBarMessage(QString,Rekonq::Notify)), this, SLOT(notifyMessage(QString,Rekonq::Notify)));
+    connect(m_view, SIGNAL(showStatusBarMessage(QString, Rekonq::Notify)), this, SLOT(notifyMessage(QString, Rekonq::Notify)));
     connect(m_view, SIGNAL(linkHovered(QString)), this, SLOT(notifyMessage(QString)));
-    connect(rApp->downloadManager(), SIGNAL(notifyDownload(QString,Rekonq::Notify)),
-            this, SLOT(notifyMessage(QString,Rekonq::Notify)));
+    connect(rApp->downloadManager(), SIGNAL(notifyDownload(QString, Rekonq::Notify)),
+            this, SLOT(notifyMessage(QString, Rekonq::Notify)));
 
     // connect signals and slots
     connect(m_view, SIGNAL(currentTitle(QString)), this, SLOT(updateWindowTitle(QString)));
@@ -214,6 +216,9 @@ MainWindow::MainWindow()
     // Save session on window closing
     connect(this, SIGNAL(windowClosing()), rApp->sessionManager(), SLOT(saveSession()));
 
+    // Adblock Manager changed rules. Reload current page
+    connect(rApp->adblockManager(), SIGNAL(reloadCurrentPage()), m_view, SLOT(webReload()));
+
     // setting up toolbars to NOT have context menu enabled
     setContextMenuPolicy(Qt::DefaultContextMenu);
 
@@ -231,6 +236,7 @@ MainWindow::~MainWindow()
 
     rApp->bookmarkManager()->removeBookmarkBar(m_bookmarksBar);
     rApp->bookmarkManager()->removeBookmarkPanel(m_bookmarksPanel);
+
     rApp->removeMainWindow(this);
 }
 
@@ -249,11 +255,11 @@ void MainWindow::setupToolbars()
 void MainWindow::postLaunch()
 {
     setupBookmarksAndToolsShortcuts();
-    
+
     // this just to fix reopening rekonq after fullscreen close
     KToolBar *mainBar = toolBar("mainToolBar");
-    mainBar->show();  
-    
+    mainBar->show();
+
     // Bookmarks Bar
     KToolBar *XMLGUIBkBar = toolBar("bookmarkToolBar");
     if (!XMLGUIBkBar)
@@ -354,7 +360,7 @@ void MainWindow::setupActions()
     a->setShortcut(fullScreenShortcut);
 
     a = actionCollection()->addAction(KStandardAction::Home);
-    connect(a, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(homePage()));
+    connect(a, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), this, SLOT(homePage()));
     KStandardAction::preferences(this, SLOT(preferences()), actionCollection());
 
     a = KStandardAction::redisplay(m_view, SLOT(webReload()), actionCollection());
@@ -395,6 +401,11 @@ void MainWindow::setupActions()
     tabAction->setDelayed(false);
     actionCollection()->addAction(QL1S("tab_list"), tabAction);
 
+    // ============================== Bookmark =======================================
+    a = KStandardAction::addBookmark(this, SLOT(bookmarkCurrentPage()), actionCollection());
+    KShortcut bkShortcut(Qt::CTRL + Qt::Key_D);
+    a->setShortcut(bkShortcut);
+
     //================================Download========================================
     a = new KAction(KIcon("download"), i18n("Downloads"), this);
     a->setShortcut(KShortcut(Qt::CTRL + Qt::Key_J));
@@ -419,8 +430,8 @@ void MainWindow::setupActions()
 
     // ========================= History related actions ==============================
     a = actionCollection()->addAction(KStandardAction::Back);
-    connect(a, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)),
-            this, SLOT(openPrevious(Qt::MouseButtons,Qt::KeyboardModifiers)));
+    connect(a, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)),
+            this, SLOT(openPrevious(Qt::MouseButtons, Qt::KeyboardModifiers)));
 
     m_historyBackMenu = new KMenu(this);
     a->setMenu(m_historyBackMenu);
@@ -428,8 +439,8 @@ void MainWindow::setupActions()
     connect(m_historyBackMenu, SIGNAL(triggered(QAction*)), this, SLOT(openActionUrl(QAction*)));
 
     a = actionCollection()->addAction(KStandardAction::Forward);
-    connect(a, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)),
-            this, SLOT(openNext(Qt::MouseButtons,Qt::KeyboardModifiers)));
+    connect(a, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)),
+            this, SLOT(openNext(Qt::MouseButtons, Qt::KeyboardModifiers)));
 
     m_historyForwardMenu = new KMenu(this);
     a->setMenu(m_historyForwardMenu);
@@ -574,8 +585,8 @@ void MainWindow::setupPanels()
     // Setup history panel
     const QString historyTitle = i18n("History Panel");
     m_historyPanel = new HistoryPanel(historyTitle, this);
-    connect(m_historyPanel, SIGNAL(openUrl(KUrl,Rekonq::OpenType)),
-            rApp, SLOT(loadUrl(KUrl,Rekonq::OpenType)));
+    connect(m_historyPanel, SIGNAL(openUrl(KUrl, Rekonq::OpenType)),
+            rApp, SLOT(loadUrl(KUrl, Rekonq::OpenType)));
     connect(m_historyPanel, SIGNAL(itemHovered(QString)), this, SLOT(notifyMessage(QString)));
     connect(m_historyPanel, SIGNAL(destroyed()), rApp, SLOT(saveConfiguration()));
 
@@ -593,8 +604,8 @@ void MainWindow::setupPanels()
     // Setup bookmarks panel
     const QString bookmarksTitle = i18n("Bookmarks Panel");
     m_bookmarksPanel = new BookmarksPanel(bookmarksTitle, this);
-    connect(m_bookmarksPanel, SIGNAL(openUrl(KUrl,Rekonq::OpenType)),
-            rApp, SLOT(loadUrl(KUrl,Rekonq::OpenType)));
+    connect(m_bookmarksPanel, SIGNAL(openUrl(KUrl, Rekonq::OpenType)),
+            rApp, SLOT(loadUrl(KUrl, Rekonq::OpenType)));
     connect(m_bookmarksPanel, SIGNAL(itemHovered(QString)), this, SLOT(notifyMessage(QString)));
     connect(m_bookmarksPanel, SIGNAL(destroyed()), rApp, SLOT(saveConfiguration()));
 
@@ -653,6 +664,7 @@ void MainWindow::finalizeGUI(KXMLGUIClient* client)
                  << " ====================== ";
 }
 
+
 void MainWindow::readProperties(const KConfigGroup& config)
 {
     Q_UNUSED(config)
@@ -660,6 +672,7 @@ void MainWindow::readProperties(const KConfigGroup& config)
     Application::instance()->sessionManager()->restoreMainWindow(this);
 }
 
+
 void MainWindow::openLocation()
 {
     if (isFullScreen())
@@ -738,9 +751,9 @@ void MainWindow::preferences()
 
     // keep us informed when the user changes settings
     connect(s, SIGNAL(settingsChanged(QString)), rApp, SLOT(updateConfiguration()));
+    connect(s, SIGNAL(finished(int)), s, SLOT(deleteLater()));
 
-    s->exec();
-    delete s;
+    s->show();
 }
 
 
@@ -1294,8 +1307,8 @@ void MainWindow::notifyMessage(const QString &msg, Rekonq::Notify status)
 
     const QPoint mousePos = mapFromGlobal(QCursor::pos());
     const QPoint bottomPoint = m_view->mapTo(this, m_view->geometry().bottomLeft());
-    // +1 because bottom() returns top() + height() - 1 , see QRect doku
-    int y = bottomPoint.y() + 1 - m_popup->height() - hScrollbarSize;
+
+    int y = bottomPoint.y() + 1 - m_popup->height() - hScrollbarSize;   // +1 because bottom() returns top() + height() - 1, see QRect doku
     int x = QRect(QPoint(0, y), labelSize).contains(mousePos) || actionBarsVisible
             ? width() - labelSize.width() - vScrollbarSize
             : 0;
@@ -1541,7 +1554,7 @@ void MainWindow::setupBookmarksAndToolsShortcuts()
         m_rekonqMenu->setButtonWidget(toolsButton);
         return;
     }
-    
+
     kWarning() << "oh oh, something went wrong with rekonq tools button...";
 }
 
@@ -1587,3 +1600,83 @@ void MainWindow::populateUserAgentMenu()
     KMenu *uaMenu = static_cast<KMenu *>(QObject::sender());
     rApp->userAgentManager()->populateUAMenuForTabUrl(uaMenu, currentTab());
 }
+
+
+void MainWindow::loadUrl(const KUrl& url,
+                         const Rekonq::OpenType& type,
+                         QWebHistory *webHistory
+                        )
+{
+    if (url.isEmpty())
+        return;
+
+    if (!url.isValid())
+    {
+        KMessageBox::error(0, i18n("Malformed URL:\n%1", url.url(KUrl::RemoveTrailingSlash)));
+        return;
+    }
+
+    Rekonq::OpenType newType = type;
+    // Don't open useless tabs or windows for actions in about: pages
+    if (url.url().contains("about:") && url.url().contains("/"))
+        newType = Rekonq::CurrentTab;
+
+    loadCheckedUrl(url, newType, webHistory);
+}
+
+
+void MainWindow::loadCheckedUrl(const KUrl& url, const Rekonq::OpenType& type, QWebHistory *webHistory)
+{
+    // NOTE: At this point, url should just be resolved via urlresolver.
+    // No need to check it twice
+
+    WebTab *tab = 0;
+    switch (type)
+    {
+    case Rekonq::NewTab:
+        tab = mainView()->newWebTab(!ReKonfig::openNewTabsInBackground());
+        break;
+    case Rekonq::NewFocusedTab:
+        tab = mainView()->newWebTab(true);
+        break;
+    case Rekonq::NewBackGroundTab:
+        tab = mainView()->newWebTab(false);
+        break;
+    case Rekonq::NewWindow:
+        rApp->loadUrl(url, type);
+        return;
+    case Rekonq::CurrentTab:
+    default:
+        tab = mainView()->currentWebTab();
+        break;
+    };
+
+    // rapidly show first loading url..
+    int tabIndex = mainView()->indexOf(tab);
+    Q_ASSERT(tabIndex != -1);
+    UrlBar *barForTab = qobject_cast<UrlBar *>(mainView()->widgetBar()->widget(tabIndex));
+    barForTab->activateSuggestions(false);
+    barForTab->setQUrl(url);
+
+    WebView *view = tab->view();
+    if (view)
+    {
+        view->load(url);
+
+        if (webHistory)
+        {
+            QByteArray historyBytes;
+            QDataStream historyStream(&historyBytes, QIODevice::ReadWrite);
+
+            historyStream << *webHistory;
+            historyStream.device()->seek(0);
+            historyStream >> *(view->history());
+        }
+    }
+}
+
+
+void MainWindow::bookmarkCurrentPage()
+{
+    currentTab()->urlBar()->manageBookmarks();
+}
