@@ -36,8 +36,9 @@
 #include <KUrl>
 
 // Qt Includes
-#include <QtCore/QObject>
-#include <QtWebKit/QWebElement>
+#include <QObject>
+#include <QString>
+#include <QWebElement>
 
 // Forward Declarations
 class KBookmark;
@@ -64,12 +65,14 @@ private:
     void browsingMenu(const KUrl &currentUrl);
 
     void favoritesPage();
-    void historyPage();
+    void historyPage(const QString & filter = QString());
     void bookmarksPage();
     void closedTabsPage();
-    void downloadsPage();
+    void downloadsPage(const QString & filter = QString());
     void tabsPage();
 
+    void loadPageForUrl(const KUrl &url, const QString & filter = QString());
+
     // --------------------------------------------------------------------------
     // "low-level" functions
     // we use these to create the pages over
@@ -80,19 +83,17 @@ private:
     QWebElement tabPreview(int winIndex, int tabIndex, const KUrl &url, const QString &title);
     QWebElement closedTabPreview(int index, const KUrl &url, const QString &title);
 
+    void reloadPreview(int index);
     void removePreview(int index);
 
-    /**
-     * This function takes a QwebElement with the .thumbnail structure,
-     * hiding the "remove" and "modify" buttons
-     *
-     */
-    void hideControls(QWebElement e);
-    void showControls(QWebElement e);
-    void setupPreview(QWebElement e, int index);
+    void setupPreview(QWebElement e, int index, bool showControls);
     void setupTabPreview(QWebElement e, int winIndex, int tabIndex);
 
-    void createBookItem(const KBookmark &bookmark, QWebElement parent);
+    void createBookmarkItem(const KBookmark &bookmark, QWebElement parent);
+    void createBookmarkGroup(const KBookmark &bookmark, QWebElement parent);
+
+    QWebElement createLinkItem(const QString &title, const QString &urlString, const QString &iconPath, int groupOrSize) const;
+    QWebElement createFormItem(const QString &title, const QString &urlString) const;
 
     /**
      * This function helps to get faster a new markup of one type,
@@ -107,15 +108,18 @@ private:
         return m_root.document().findFirst("#models > " + selector).clone();
     }
 
-    QString checkTitle(const QString &title);
+    QString checkTitle(const QString &title, int max = 20);
 
     void updateWindowIcon();
 
-private:
-    QWebElement createLinkItem(const QString &title, const QString &urlString, const QString &iconPath, int groupOrSize) const;
+    void initJS();
+    void saveFavorites();
 
+private:
     QString m_html;
     QWebElement m_root;
+
+    bool m_showFullHistory;
 };
 
 #endif // REKONQ_NEW_TAB_PAGE
