@@ -31,10 +31,10 @@
 #include "opensearchmanager.moc"
 
 // Local Includes
+#include "application.h"
 #include "opensearchengine.h"
 #include "opensearchreader.h"
 #include "opensearchwriter.h"
-#include "application.h"
 
 // KDE Includes
 #include <KGlobal>
@@ -47,8 +47,8 @@
 #include <KConfigGroup>
 
 // Qt Includes
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
+#include <QFile>
+#include <QFileInfo>
 #include <QDBusMessage>
 #include <QDBusConnection>
 
@@ -126,10 +126,11 @@ void OpenSearchManager::addOpenSearchEngine(const KUrl &url, const QString &titl
     m_currentJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
     m_jobUrl = url;
     m_state = REQ_DESCRIPTION;
-    connect(m_currentJob, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(dataReceived(KIO::Job*,QByteArray)));
+    connect(m_currentJob, SIGNAL(data(KIO::Job*, QByteArray)), this, SLOT(dataReceived(KIO::Job*, QByteArray)));
     connect(m_currentJob, SIGNAL(result(KJob*)), this, SLOT(jobFinished(KJob*)));
 }
 
+
 void OpenSearchManager::requestSuggestion(const QString &searchText)
 {
     if (!m_activeEngine)
@@ -154,7 +155,7 @@ void OpenSearchManager::requestSuggestion(const QString &searchText)
         _typedText = searchText;
         m_currentJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
         m_state = REQ_SUGGESTION;
-        connect(m_currentJob, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(dataReceived(KIO::Job*,QByteArray)));
+        connect(m_currentJob, SIGNAL(data(KIO::Job*, QByteArray)), this, SLOT(dataReceived(KIO::Job*, QByteArray)));
         connect(m_currentJob, SIGNAL(result(KJob*)), this, SLOT(jobFinished(KJob*)));
     }
 }
@@ -221,7 +222,7 @@ void OpenSearchManager::jobFinished(KJob *job)
         idleJob();
         return;
     }
-    
+
     // Do NOT parse if job had same errors or the typed string is empty
     if (job->error() || _typedText.isEmpty())
     {
