@@ -40,12 +40,12 @@
 #include <kio/jobclasses.h>
 
 // Qt Includes
-#include <QtCore/QObject>
-#include <QFile>
+#include <QObject>
 
 // Forward Declarations
 class OpenSearchEngine;
 
+
 /**
  * This class acts as a proxy between the SearchBar plugin
  * and the individual suggestion engine.
