@@ -31,7 +31,6 @@
 #include "rekonq.h"
 
 // Local Includes
-#include "adblockmanager.h"
 #include "application.h"
 #include "historymanager.h"
 #include "mainview.h"
@@ -44,6 +43,7 @@
 // KDE Includes
 #include <KIO/Job>
 #include <KDirLister>
+#include <KLocale>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KProcess>
@@ -53,8 +53,8 @@
 #include <KRun>
 
 // Qt Includes
-#include <QtNetwork/QNetworkRequest>
-#include <QtWebKit/QWebFrame>
+#include <QNetworkRequest>
+#include <QWebFrame>
 #include <QTextDocument>
 
 
@@ -125,13 +125,6 @@ bool ProtocolHandler::preHandling(const QNetworkRequest &request, QWebFrame *fra
         return true;
     }
 
-    // "abp" handling
-    if (_url.protocol() == QL1S("abp"))
-    {
-        abpHandling();
-        return true;
-    }
-
     // "about" handling
     if (_url.protocol() == QL1S("about"))
     {
@@ -193,7 +186,7 @@ bool ProtocolHandler::preHandling(const QNetworkRequest &request, QWebFrame *fra
         (void)new KRun(_url, rApp->mainWindow(), 0, _url.isLocalFile());
         return true;
     }
-    
+
     // let webkit try to load a known (or missing) protocol...
     if (KProtocolInfo::isKnownProtocol(_url))
         return false;
@@ -245,6 +238,8 @@ bool ProtocolHandler::postHandling(const QNetworkRequest &request, QWebFrame *fr
 
             return true;
         }
+
+        return false;
     }
 
     // we cannot handle this protocol in any way.
@@ -276,7 +271,7 @@ void ProtocolHandler::showResults(const KFileItemList &list)
 
         rApp->mainWindow()->mainView()->currentUrlBar()->setQUrl(_url);
         rApp->mainWindow()->currentTab()->setFocus();
-        rApp->historyManager()->addHistoryEntry(_url.prettyUrl());
+        rApp->historyManager()->addHistoryEntry(_url, _url.prettyUrl());
     }
 }
 
@@ -301,8 +296,15 @@ QString ProtocolHandler::dirHandling(const KFileItemList &list)
         return QString("rekonq error, sorry :(");
     }
 
+    // 1. default data path
+    QString dataPath = QL1S("file://") + infoFilePath;
+    dataPath.remove(QL1S("/htmls/rekonqinfo.html"));
+
+    // 2. title
     QString title = _url.prettyUrl();
-    QString msg = i18nc("%1=an URL", "<h1>Index of %1</h1>", _url.prettyUrl());
+
+    // 3. main content
+    QString msg = i18nc("%1=an URL", "<h2>Index of %1</h2>", _url.prettyUrl());
 
 
     if (rootUrl.cd(".."))
@@ -313,43 +315,48 @@ QString ProtocolHandler::dirHandling(const KFileItemList &list)
         msg += "<a href=\"" + path + "\">" + i18n("Up to higher level directory") + "</a><br /><br />";
     }
 
-    msg += "<table width=\"100%\">";
-    msg += "<tr><th align=\"left\">" + i18n("Name") + "</th><th>" + i18n("Size") + "</th><th>" + i18n("Last Modified") + "</th></tr>";
+    msg += QL1S("<table width=\"95%\" align=\"center\">");
+    msg += QL1S("<tr>");
+    msg += QL1S("<th align=\"left\">") + i18n("Name") + QL1S("</th>");
+    msg += QL1S("<th align=\"center\">") + i18n("Size") + QL1S("</th>");
+    msg += QL1S("<th align=\"right\">") + i18n("Last Modified") + QL1S("</th>");
+    msg += QL1S("</tr>");
 
     KFileItemList orderedList = sortFileList(list);
     Q_FOREACH(const KFileItem & item, orderedList)
     {
-        msg += "<tr>";
+        msg += QL1S("<tr>");
         QString fullPath = Qt::escape(item.url().prettyUrl());
 
         QString iconName = item.iconName();
         QString icon = QString("file://") + KIconLoader::global()->iconPath(iconName, KIconLoader::Small);
 
-        msg += "<td width=\"70%\">";
-        msg += "<img src=\"" + icon + "\" alt=\"" + iconName + "\" /> ";
-        msg += "<a href=\"" + fullPath + "\">" + Qt::escape(item.name()) + "</a>";
-        msg += "</td>";
+        msg += QL1S("<td width=\"70%\">");
+        msg += QL1S("<img src=\"") + icon + QL1S("\" alt=\"") + iconName + QL1S("\" /> ");
+        msg += QL1S("<a href=\"") + fullPath + QL1S("\">") + Qt::escape(item.name()) + QL1S("</a>");
+        msg += QL1S("</td>");
 
-        msg += "<td align=\"right\">";
+        msg += QL1S("<td align=\"right\">");
         if (item.isFile())
         {
             msg += KGlobal::locale()->formatByteSize(item.size(), 1);
         }
-        msg += "</td>";
+        msg += QL1S("</td>");
 
-        msg += "<td align=\"right\">";
+        msg += QL1S("<td align=\"right\">");
         msg += item.timeString();
-        msg += "</td>";
+        msg += QL1S("</td>");
 
-        msg += "</tr>";
+        msg += QL1S("</tr>");
     }
-    msg += "</table>";
+    msg += QL1S("</table>");
 
+    // done. Replace variables and show it
+    QString html = QL1S(file.readAll());
 
-    QString html = QString(QL1S(file.readAll()))
-                   .arg(title)
-                   .arg(msg)
-                   ;
+    html.replace(QL1S("$DEFAULT_PATH"), dataPath);
+    html.replace(QL1S("$PAGE_TITLE"), title);
+    html.replace(QL1S("$MAIN_CONTENT"), msg);
 
     return html;
 }
@@ -377,48 +384,3 @@ void ProtocolHandler::slotMostLocalUrlResult(KJob *job)
         }
     }
 }
-
-
-/**
- * abp scheme (easy) explanation
- *
- */
-void ProtocolHandler::abpHandling()
-{
-    QString path = _url.path();
-    if (path != QL1S("subscribe"))
-        return;
-
-    QMap<QString, QString> map = _url.queryItems(KUrl::CaseInsensitiveKeys);
-
-    QString location = map.value(QL1S("location"));
-    QString title = map.value(QL1S("title"));
-    QString requireslocation = map.value(QL1S("requireslocation"));
-    QString requirestitle = map.value(QL1S("requirestitle"));
-
-    QString info;
-    if (requirestitle.isEmpty() || requireslocation.isEmpty())
-    {
-        info = title;
-    }
-    else
-    {
-        info = i18n("\n %1,\n %2 (required by %3)\n", title, requirestitle, title);
-    }
-
-    if (KMessageBox::questionYesNo(0,
-                                   i18n("Do you want to add the following subscriptions to your adblock settings?\n") + info,
-                                   i18n("Add automatic subscription to the adblock"),
-                                   KGuiItem(i18n("Add")),
-                                   KGuiItem(i18n("Discard"))
-                                  )
-       )
-    {
-        if (!requireslocation.isEmpty() && !requirestitle.isEmpty())
-        {
-            rApp->adblockManager()->addSubscription(requirestitle, requireslocation);
-        }
-        rApp->adblockManager()->addSubscription(title, location);
-        rApp->adblockManager()->loadSettings(false);
-    }
-}
