@@ -35,7 +35,7 @@
 #include <KUrl>
 
 // Qt Includes
-#include <QtCore/QObject>
+#include <QObject>
 
 // Forward Declarations
 class KDirLister;
@@ -74,7 +74,6 @@ private Q_SLOTS:
 
 private:
     QString dirHandling(const KFileItemList &list);
-    void abpHandling();
 
     KDirLister *_lister;
     QWebFrame *_frame;
