@@ -34,10 +34,10 @@
 #include "rekonq_defines.h"
 
 // Qt Includes
-#include <QtCore/QObject>
+#include <QObject>
+#include <QString>
 
 // Forward Declarations
-class QString;
 class TabHistory;
 class MainWindow;
 
