@@ -55,10 +55,6 @@ GeneralWidget::GeneralWidget(QWidget *parent)
 
     checkKGetPresence();
 
-    KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig("kioslaverc", KConfig::NoGlobals), QString());
-    doNotTrackCheckBox->setChecked(cg.readEntry("DoNotTrack", false));
-
-    connect(doNotTrackCheckBox, SIGNAL(clicked()), this, SLOT(hasChanged()));
     connect(kcfg_homePage, SIGNAL(editingFinished()), this, SLOT(fixHomePageURL()));
 
     kcfg_downloadPath->setMode(KFile::Directory);
@@ -76,10 +72,6 @@ void GeneralWidget::save()
 {
     ReKonfig::setAskDownloadPath(askDownloadYes->isChecked());
 
-    KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig("kioslaverc", KConfig::NoGlobals), QString());
-    cg.writeEntry("DoNotTrack", doNotTrackCheckBox->isChecked());
-    cg.sync();
-
     _changed = false;
 }
 
@@ -121,8 +113,7 @@ void GeneralWidget::checkKGetPresence()
     {
         kcfg_kgetDownload->setDisabled(true);
         kcfg_kgetList->setDisabled(true);
-        kcfg_kgetDownload->setToolTip(i18n("Install KGet to enable rekonq to use KGet as download manager"));
-
+        kcfg_kgetDownload->setToolTip(i18n("Install KGet to enable rekonq to use it as download manager"));
     }
     else
     {
