@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2011-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -39,9 +39,11 @@ class SyncAssistant : public QWizard
 public:
     enum
     {
-        Page_Data,
         Page_Type,
         Page_FTP_Settings,
+        Page_Google_Settings,
+        Page_Opera_Settings,
+        Page_Data,
         Page_Check
     };
 
