@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2011-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -47,18 +47,8 @@ public:
 
     int nextId() const;
 
-    bool changed();
+    void initializePage();
 
-Q_SIGNALS:
-    void changed(bool);
-
-private Q_SLOTS:
-    void hasChanged();
-
-private:
-    void enablewidgets(bool);
-
-    bool _changed;
 };
 
 #endif // SYNC_WIDGET_H
