@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2011-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -46,6 +46,18 @@ public:
     SyncHostTypeWidget(QWidget *parent = 0);
 
     int nextId() const;
+    bool changed();
+
+Q_SIGNALS:
+    void changed(bool);
+
+private Q_SLOTS:
+    void hasChanged();
+
+private:
+    void enablewidgets(bool b);
+    bool _changed;
+
 };
 
 #endif // SYNC_HOST_TYPE_WIDGET_H
