@@ -24,18 +24,25 @@
 * ============================================================ */
 
 
-//Self Includes
+// Self Includes
 #include "tabhighlighteffect.h"
 #include "tabhighlighteffect.moc"
 
-//Qt Includes
+// Local Includes
+#include "tabbar.h"
+
+// Qt Includes
+#include <QEvent>
+#include <QPainter>
 #include <QVariant>
-#include <tabbar.h>
 
 
 const QByteArray prep("hAnim");
 
 
+// ---------------------------------------------------------------------------
+
+
 TabHighlightEffect::TabHighlightEffect(TabBar *tabBar)
     : QGraphicsEffect(tabBar)
     , m_tabBar(tabBar)
