@@ -75,11 +75,11 @@ class TabBarTest : public QObject
 {
     Q_OBJECT
 
-public slots:
+public Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
 
-private slots:
+private Q_SLOTS:
     void tabSizeHint_data();
     void tabSizeHint();
 
