@@ -49,7 +49,6 @@
 #include <QActionGroup>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
-#include <QLabel>
 #include <QSizePolicy>
 #include <QPixmap>
 #include <QStylePainter>
@@ -392,15 +391,15 @@ ImageLabel::ImageLabel(const QString &url, int width, int height, QWidget *paren
     else
     {
         KIO::TransferJob *job = KIO::get(KUrl(url), KIO::NoReload, KIO::HideProgressInfo);
-        connect(job,  SIGNAL(data(KIO::Job*,QByteArray)),
-                this, SLOT(slotData(KIO::Job*,QByteArray)));
+        connect(job,  SIGNAL(data(KIO::Job*, QByteArray)),
+                this, SLOT(slotData(KJob*, QByteArray)));
         connect(job,  SIGNAL(result(KJob*)),
                 this, SLOT(slotResult(KJob*)));
     }
 }
 
 
-void ImageLabel::slotData(KIO::Job *job, const QByteArray &data)
+void ImageLabel::slotData(KJob *job, const QByteArray &data)
 {
     Q_UNUSED(job);
     m_data.append(data);
