@@ -31,22 +31,25 @@
 // Rekonq Includes
 #include "rekonq_defines.h"
 
-// Local Includes
-#include "urlresolver.h"
-
 // KDE Includes
 #include <KToolBar>
 #include <KService>
-#include <KIcon>
+#include <KUrl>
 
 // Qt Includes
 #include <QWidget>
-#include <QStyleOptionViewItemV4>
 #include <QLabel>
+#include <QStyleOptionViewItemV4>
+#include <QString>
+#include <QByteArray>
 
 // Forward Declarations
 class UrlSearchItem;
+
 class KAction;
+class KIcon;
+class KJob;
+
 class QActionGroup;
 
 
@@ -258,7 +261,7 @@ private:
     QByteArray m_data;
 
 private Q_SLOTS:
-    void slotData(KIO::Job* job, const QByteArray& data);
+    void slotData(KJob* job, const QByteArray& data);
     void slotResult(KJob* job);
 };
 
