@@ -47,21 +47,25 @@
 #include "iconmanager.h"
 #include "favoritewidget.h"
 #include "searchengine.h"
+#include "websnap.h"
 
 // KDE Includes
 #include <KCompletionBox>
 #include <KStandardDirs>
 #include <KColorScheme>
 #include <KMenu>
+#include <KIconLoader>
 
 // Qt Includes
-#include <QtGui/QPainter>
-#include <QtGui/QPaintEvent>
-#include <QtGui/QPalette>
-#include <QtGui/QVBoxLayout>
+#include <QPainter>
+#include <QPaintEvent>
+#include <QPalette>
+#include <QVBoxLayout>
 #include <QClipboard>
 #include <QTimer>
 
+// const values
+const int c_iconMargin = 4;
 
 
 IconButton::IconButton(QWidget *parent)
@@ -70,6 +74,8 @@ IconButton::IconButton(QWidget *parent)
     setToolButtonStyle(Qt::ToolButtonIconOnly);
     setStyleSheet("IconButton { background-color:transparent; border: none; padding: 0px}");
     setCursor(Qt::ArrowCursor);
+
+    setContextMenuPolicy(Qt::PreventContextMenu);
 }
 
 
@@ -103,8 +109,13 @@ UrlBar::UrlBar(QWidget *parent)
     , _icon(new IconButton(this))
     , _suggestionTimer(new QTimer(this))
 {
+    setLayoutDirection(Qt::LeftToRight);
+
+    // set initial icon
+    _icon->setIcon(KIcon("arrow-right"));
+
     // initial style
-    setStyleSheet(QString("UrlBar { padding: 2px 0 2px %1px;} ").arg(_icon->sizeHint().width()));
+    setStyleSheet(QString("UrlBar { padding: 2px 0 2px %1px; height: %1px } ").arg(_icon->sizeHint().width()));
 
     // doesn't show the clear button
     setClearButtonShown(false);
@@ -359,19 +370,13 @@ void UrlBar::loadFinished()
         return;
     }
 
-    // Make sure icons aren't duplicated
-    clearRightIcons();
-
-    // show Favorite Icon
-    if (ReKonfig::previewUrls().contains(_tab->url().url()))
-    {
-        IconButton *bt = addRightIcon(UrlBar::Favorite);
-        connect(bt, SIGNAL(clicked(QPoint)), this, SLOT(showFavoriteDialog(QPoint)));
-    }
-
     // show bookmark info
     IconButton *bt = addRightIcon(UrlBar::BK);
-    connect(bt, SIGNAL(clicked(QPoint)), this, SLOT(showBookmarkInfo(QPoint)));
+    connect(bt, SIGNAL(clicked(QPoint)), this, SLOT(manageBookmarks()));
+
+    // show favorite icon
+    IconButton *fbt = addRightIcon(UrlBar::Favorite);
+    connect(fbt, SIGNAL(clicked(QPoint)), this, SLOT(manageFavorites(QPoint)));
 
     // show KGet downloads??
     if (!KStandardDirs::findExe("kget").isNull() && ReKonfig::kgetList())
@@ -402,37 +407,19 @@ void UrlBar::loadFinished()
         connect(bt, SIGNAL(clicked(QPoint)), _tab, SLOT(showSearchEngine(QPoint)));
     }
 
+    if (_tab->hasAdBlockedElements())
+    {
+        IconButton *bt = addRightIcon(UrlBar::AdBlock);
+
+        connect(bt, SIGNAL(clicked(QPoint)), (QObject *) rApp->adblockManager(), SLOT(showBlockedItemDialog()));
+    }
+
     // we need to update urlbar after the right icon settings
     // removing this code (where setStyleSheet automatically calls update) needs adding again
     // an update call
-    int rightIconWidth = 25 * (_rightIconsList.count());
-    setStyleSheet(QString("UrlBar { padding: 2px %2px 2px %1px;} ").arg(_icon->sizeHint().width()).arg(rightIconWidth));
-}
-
-
-void UrlBar::showBookmarkDialog()
-{
-    showBookmarkInfo(QCursor::pos());
-}
-
-
-void UrlBar::showBookmarkInfo(QPoint pos)
-{
-    if (_tab->url().scheme() == QL1S("about"))
-        return;
-
-    KBookmark bookmark = rApp->bookmarkManager()->bookmarkForUrl(_tab->url());
-
-    if (bookmark.isNull())
-    {
-        bookmark = rApp->bookmarkManager()->owner()->bookmarkCurrentPage();
-    }
-    else
-    {
-        BookmarkWidget *widget = new BookmarkWidget(bookmark, window());
-//         connect(widget, SIGNAL(updateIcon()), this, SLOT(updateRightIcons()));
-        widget->showAt(pos);
-    }
+    int oneIconWidth = _icon->sizeHint().width();
+    int rightIconWidth = (oneIconWidth + c_iconMargin) * (_rightIconsList.count());
+    setStyleSheet(QString("UrlBar { padding: 2px %2px 2px %1px; height: %1px } ").arg(oneIconWidth).arg(rightIconWidth));
 }
 
 
@@ -440,6 +427,7 @@ void UrlBar::updateRightIcons()
 {
     if (!_tab->isPageLoading())
     {
+        clearRightIcons();
         loadFinished();
     }
 }
@@ -453,7 +441,7 @@ void UrlBar::activateSuggestions(bool b)
         {
             _box = new CompletionWidget(this);
             installEventFilter(_box.data());
-            connect(_box.data(), SIGNAL(chosenUrl(KUrl,Rekonq::OpenType)), this, SLOT(loadRequestedUrl(KUrl,Rekonq::OpenType)));
+            connect(_box.data(), SIGNAL(chosenUrl(KUrl, Rekonq::OpenType)), this, SLOT(loadRequestedUrl(KUrl, Rekonq::OpenType)));
 
             // activate suggestions on edit text
             connect(this, SIGNAL(textChanged(QString)), this, SLOT(detectTypedString(QString)));
@@ -581,8 +569,6 @@ IconButton *UrlBar::addRightIcon(UrlBar::icon ic)
             rightIcon->setIcon(KIcon("bookmarks"));
             rightIcon->setToolTip(i18n("Edit this bookmark"));
         }
-        rightIcon->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(rightIcon, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(bookmarkContextMenu(QPoint)));
         break;
     case UrlBar::SearchEngine:
     {
@@ -596,8 +582,20 @@ IconButton *UrlBar::addRightIcon(UrlBar::icon ic)
         break;
     }
     case UrlBar::Favorite:
-        rightIcon->setIcon(KIcon("emblem-favorite"));
-        rightIcon->setToolTip(i18n("Remove from favorite"));
+        if (ReKonfig::previewUrls().contains(_tab->url().url()))
+        {
+            rightIcon->setIcon(KIcon("emblem-favorite"));
+            rightIcon->setToolTip(i18n("Remove from favorite"));
+        }
+        else
+        {
+            rightIcon->setIcon(KIcon("emblem-favorite").pixmap(32, 32, QIcon::Disabled));
+            rightIcon->setToolTip(i18n("Add to favorites"));
+        }
+        break;
+    case UrlBar::AdBlock:
+        rightIcon->setIcon(KIcon("preferences-web-browser-adblock"));
+        rightIcon->setToolTip(i18n("There are elements blocked by AdBlock"));
         break;
     default:
         ASSERT_NOT_REACHED("ERROR.. default non extant case!!");
@@ -605,9 +603,10 @@ IconButton *UrlBar::addRightIcon(UrlBar::icon ic)
     }
 
     _rightIconsList << rightIcon;
+
     int iconsCount = _rightIconsList.count();
-    int iconHeight = (height() - 18) / 2;
-    rightIcon->move(width() - 23 * iconsCount, iconHeight);
+    updateRightIconPosition(rightIcon, iconsCount);
+
     rightIcon->show();
 
     return rightIcon;
@@ -623,16 +622,16 @@ void UrlBar::clearRightIcons()
 
 void UrlBar::resizeEvent(QResizeEvent *event)
 {
-    int newHeight = (height() - 18) / 2;
-    _icon->move(4, newHeight);
-
+    int ih = _icon->sizeHint().height();
     int iconsCount = _rightIconsList.count();
-    int w = width();
+    int iconHeight = (height() - ih) / 2;
+
+    _icon->move(c_iconMargin, iconHeight);
 
     for (int i = 0; i < iconsCount; ++i)
     {
         IconButton *bt = _rightIconsList.at(i);
-        bt->move(w - 25 * (i + 1), newHeight);
+        updateRightIconPosition(bt, i + 1);
     }
 
     KLineEdit::resizeEvent(event);
@@ -678,64 +677,6 @@ void UrlBar::refreshFavicon()
 }
 
 
-void UrlBar::showFavoriteDialog(QPoint pos)
-{
-    if (_tab->url().scheme() == QL1S("about"))
-        return;
-
-    IconButton *bt = qobject_cast<IconButton *>(this->sender());
-    if (!bt)
-        return;
-
-    FavoriteWidget *widget = new FavoriteWidget(_tab, window());
-    connect(widget, SIGNAL(updateIcon()), this, SLOT(updateRightIcons()));
-    widget->showAt(pos);
-}
-
-
-void UrlBar::bookmarkContextMenu(QPoint pos)
-{
-    Q_UNUSED(pos);
-
-    KMenu menu(this);
-    QAction *qa;
-
-    if (!rApp->bookmarkManager()->bookmarkForUrl(_tab->url()).isNull())
-    {
-        qa = new KAction(KIcon("bookmarks"), i18n("Edit Bookmark"), this);
-        connect(qa, SIGNAL(triggered(bool)), this, SLOT(showBookmarkDialog()));
-        menu.addAction(qa);
-    }
-
-    if (!ReKonfig::previewUrls().contains(_tab->url().url()))
-    {
-        qa = new KAction(KIcon("emblem-favorite"), i18n("Add to favorite"), this);
-        connect(qa, SIGNAL(triggered(bool)), this, SLOT(addFavorite()));
-        menu.addAction(qa);
-    }
-
-    menu.exec(QCursor::pos());
-}
-
-
-
-void UrlBar::addFavorite()
-{
-    if (ReKonfig::previewUrls().contains(_tab->url().url()))
-        return;
-
-    QStringList urls = ReKonfig::previewUrls();
-    urls << _tab->url().url();
-    ReKonfig::setPreviewUrls(urls);
-
-    QStringList titles = ReKonfig::previewNames();
-    titles << _tab->view()->title();
-    ReKonfig::setPreviewNames(titles);
-
-    updateRightIcons();
-}
-
-
 void UrlBar::pasteAndGo()
 {
     loadRequestedUrl(rApp->clipboard()->text());
@@ -754,3 +695,79 @@ void UrlBar::delSlot()
 {
     del();
 }
+
+
+void UrlBar::manageBookmarks()
+{
+    if (_tab->url().scheme() == QL1S("about"))
+        return;
+
+    KBookmark bookmark = rApp->bookmarkManager()->bookmarkForUrl(_tab->url());
+
+    if (bookmark.isNull())
+    {
+        bookmark = rApp->bookmarkManager()->owner()->bookmarkCurrentPage();
+    }
+
+    // calculate position
+    int iconSize = IconSize(KIconLoader::Small) + c_iconMargin;
+
+    // Add a generic 10 to move it a bit below and right.
+    // No need to be precise...
+    int iconWidth = 10 + width() - ((iconSize + c_iconMargin));
+    int iconHeight = 10 + (height() - iconSize) / 2;
+
+    QPoint p = mapToGlobal(QPoint(iconWidth, iconHeight));
+
+    // show bookmark widget
+    BookmarkWidget *widget = new BookmarkWidget(bookmark, window());
+    widget->showAt(p);
+}
+
+
+void UrlBar::manageFavorites(QPoint pos)
+{
+    IconButton *bt = qobject_cast<IconButton *>(this->sender());
+    if (!bt)
+        return;
+
+    if (_tab->url().scheme() == QL1S("about"))
+        return;
+
+    if (ReKonfig::previewUrls().contains(_tab->url().url()))
+    {
+        // remove site from favorites
+        FavoriteWidget *widget = new FavoriteWidget(_tab, window());
+        connect(widget, SIGNAL(updateIcon()), this, SLOT(updateRightIcons()));
+        widget->showAt(pos);
+        return;
+    }
+
+    // else, add as favorite
+    QStringList urls = ReKonfig::previewUrls();
+    urls << _tab->url().url();
+    ReKonfig::setPreviewUrls(urls);
+
+    QStringList titles = ReKonfig::previewNames();
+    titles << _tab->view()->title();
+    ReKonfig::setPreviewNames(titles);
+
+    // also, save a site snapshot
+    WebSnap *snap = new WebSnap(_tab->url(), this);
+
+    updateRightIcons();
+}
+
+
+void UrlBar::updateRightIconPosition(IconButton *icon, int iconsCount)
+{
+    // NOTE: cannot show a (let's say) 16x16 icon in a 16x16 square.
+    // It needs some margin. It usually is 3, but using 4 (default rekonq icon margin)
+    // seems NOT a big problem and let's us using just one const ;)
+    int iconSize = IconSize(KIconLoader::Small) + c_iconMargin;
+
+    int iconWidth = width() - ((iconSize + c_iconMargin) * iconsCount);
+    int iconHeight = (height() - iconSize) / 2;
+
+    icon->move(iconWidth, iconHeight);
+}
