@@ -83,7 +83,8 @@ public:
         SSL          = 0x00000100,
         BK           = 0x00001000,
         SearchEngine = 0x00010000,
-        Favorite     = 0x00100000
+        Favorite     = 0x00100000,
+        AdBlock      = 0x01000000
     };
 
     explicit UrlBar(QWidget *parent = 0);
@@ -94,6 +95,12 @@ public:
 public Q_SLOTS:
     void setQUrl(const QUrl &url);
 
+    /**
+     * Let us add bookmarks as the major browsers do
+     *
+     */
+    void manageBookmarks();
+
 private Q_SLOTS:
     void loadRequestedUrl(const KUrl& url, Rekonq::OpenType = Rekonq::CurrentTab);
 
@@ -105,12 +112,7 @@ private Q_SLOTS:
     void detectTypedString(const QString &);
     void suggest();
 
-    void showBookmarkInfo(QPoint);
-    void showBookmarkDialog();
-
-    void showFavoriteDialog(QPoint);
-    void bookmarkContextMenu(QPoint);
-    void addFavorite();
+    void manageFavorites(QPoint);
 
     void refreshFavicon();
 
@@ -134,6 +136,11 @@ protected:
     void resizeEvent(QResizeEvent *);
 
 private:
+    /**
+     * Updates right icon position, given its number in the right icons list
+     * and considering rekonq window position/dimension
+     */
+    void updateRightIconPosition(IconButton *, int);
     IconButton *addRightIcon(UrlBar::icon);
 
     QWeakPointer<CompletionWidget> _box;
