@@ -41,6 +41,7 @@
 #include "adblockmanager.h"
 #include "application.h"
 #include "downloadmanager.h"
+#include "historymanager.h"
 #include "iconmanager.h"
 #include "mainview.h"
 #include "mainwindow.h"
@@ -72,6 +73,7 @@
 // Qt Includes
 #include <QTextDocument>
 #include <QFileInfo>
+#include <QNetworkReply>
 
 
 // Returns true if the scheme and domain of the two urls match...
@@ -126,13 +128,16 @@ WebPage::WebPage(QWidget *parent)
     , _networkAnalyzer(false)
     , _isOnRekonqPage(false)
 {
-    // ----- handling unsupported content...
+    // handling unsupported content...
     setForwardUnsupportedContent(true);
     connect(this, SIGNAL(unsupportedContent(QNetworkReply*)), this, SLOT(handleUnsupportedContent(QNetworkReply*)));
 
-    // ----- rekonq Network Manager
+    // rekonq Network Manager
     NetworkAccessManager *manager = new NetworkAccessManager(this);
 
+    // set network reply object to emit readyRead when it receives meta data
+    manager->setEmitReadyReadOnMetaDataChange(true);
+
     // disable QtWebKit cache to just use KIO one..
     manager->setCache(0);
 
@@ -140,9 +145,6 @@ WebPage::WebPage(QWidget *parent)
     if (parent && parent->window())
         manager->setWindow(parent->window());
 
-    // set network reply object to emit readyRead when it receives meta data
-    manager->setEmitReadyReadOnMetaDataChange(true);
-
     setNetworkAccessManager(manager);
 
     // activate ssl warnings
@@ -211,7 +213,7 @@ QString WebPage::suggestedFileName()
     return _suggestedFileName;
 };
 
-    
+
 bool WebPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request, NavigationType type)
 {
     if (_isOnRekonqPage)
@@ -226,17 +228,7 @@ bool WebPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &r
     _suggestedFileName.clear();
     _loadingUrl = request.url();
 
-    KIO::AccessManager *manager = qobject_cast<KIO::AccessManager*>(networkAccessManager());
-    KIO::MetaData metaData = manager->requestMetaData();
-
-    // Get the SSL information sent, if any...
-    if (metaData.contains(QL1S("ssl_in_use")))
-    {
-        WebSslInfo info;
-        info.restoreFrom(metaData.toVariant(), request.url());
-        info.setUrl(request.url());
-        _sslInfo = info;
-    }
+    const bool isMainFrameRequest = (frame == mainFrame());
 
     if (frame)
     {
@@ -269,15 +261,43 @@ bool WebPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &r
             break;
 
         case QWebPage::NavigationTypeReload:
+            setRequestMetaData(QL1S("cache"), QL1S("reload"));
+            break;
+
         case QWebPage::NavigationTypeBackOrForward:
         case QWebPage::NavigationTypeOther:
             break;
 
         default:
-            ASSERT_NOT_REACHED();
+            ASSERT_NOT_REACHED(unknown NavigationType);
             break;
         }
     }
+
+    // Get the SSL information sent, if any...
+    KIO::AccessManager *manager = qobject_cast<KIO::AccessManager*>(networkAccessManager());
+    KIO::MetaData metaData = manager->requestMetaData();
+    if (metaData.contains(QL1S("ssl_in_use")))
+    {
+        WebSslInfo info;
+        info.restoreFrom(metaData.toVariant(), request.url());
+        info.setUrl(request.url());
+        _sslInfo = info;
+    }
+
+    if (isMainFrameRequest)
+    {
+        setRequestMetaData(QL1S("main_frame_request"), QL1S("TRUE"));
+        if (_sslInfo.isValid() && !domainSchemeMatch(request.url(), _sslInfo.url()))
+        {
+            _sslInfo = WebSslInfo();
+        }
+    }
+    else
+    {
+        setRequestMetaData(QL1S("main_frame_request"), QL1S("FALSE"));
+    }
+
     return KWebPage::acceptNavigationRequest(frame, request, type);
 }
 
@@ -348,6 +368,19 @@ void WebPage::handleUnsupportedContent(QNetworkReply *reply)
         return;
     }
 
+    // NOTE
+    // This is needed in case rekonq has been associated with something it cannot
+    // properly handle (eg: xbel files, see BUG:299056). This way we break an eventual
+    // "recall" loop.
+    if (appService->exec().trimmed().startsWith(QL1S("rekonq")))
+    {
+        isLocal
+        ? KMessageBox::sorry(view(), i18n("rekonq cannot properly handle this, sorry"))
+        : downloadUrl(reply->url());
+
+        return;
+    }
+
     if (isLocal)
     {
         // Load outside local files
@@ -427,12 +460,8 @@ void WebPage::handleUnsupportedContent(QNetworkReply *reply)
 
 void WebPage::loadStarted()
 {
-}
-
-
-void WebPage::loadFinished(bool ok)
-{
-    Q_UNUSED(ok);
+    _hasAdBlockedElements = false;
+    rApp->adblockManager()->clearElementsLists();
 
     // set zoom factor
     QString val;
@@ -441,7 +470,14 @@ void WebPage::loadFinished(bool ok)
     val = group.readEntry(_loadingUrl.host(), QString("10"));
 
     int value = val.toInt();
-    mainFrame()->setZoomFactor(QVariant(value).toReal() / 10);  // Don't allox max +1 values
+    if (value != 10)
+        mainFrame()->setZoomFactor(QVariant(value).toReal() / 10);  // Don't allox max +1 values
+}
+
+
+void WebPage::loadFinished(bool ok)
+{
+    Q_UNUSED(ok);
 
     // Provide site icon. Can this be moved to loadStarted??
     rApp->iconManager()->provideIcon(mainFrame(), _loadingUrl);
@@ -465,26 +501,30 @@ void WebPage::manageNetworkErrors(QNetworkReply *reply)
     Q_ASSERT(reply);
 
     QWebFrame* frame = qobject_cast<QWebFrame *>(reply->request().originatingObject());
-    const bool isMainFrameRequest = (frame == mainFrame());
-    const bool isLoadingUrlReply = (mainFrame()->url() == reply->url());
+    if (!frame)
+        return;
 
-    if (isMainFrameRequest
-            && _sslInfo.isValid()
-            && isLoadingUrlReply
-            && !domainSchemeMatch(reply->url(), _sslInfo.url())
-       )
+    const bool isMainFrameRequest = (frame == mainFrame());
+
+    // Only deal with non-redirect responses...
+    const QVariant redirectVar = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
+    if (redirectVar.isValid())
     {
-        // Reseting cached SSL info...
-        _sslInfo = WebSslInfo();
+        _sslInfo.restoreFrom(reply->attribute(static_cast<QNetworkRequest::Attribute>(KIO::AccessManager::MetaData)), reply->url());
+        return;
     }
 
+    // We are just managing loading URLs errors
+    if (reply->request().url() != _loadingUrl)
+        return;
+
     // NOTE: These are not all networkreply errors,
     // but just that supported directly by KIO
     switch (reply->error())
     {
 
     case QNetworkReply::NoError:                             // no error. Simple :)
-        if (isMainFrameRequest && isLoadingUrlReply && !_sslInfo.isValid())
+        if (isMainFrameRequest)
         {
             // Obtain and set the SSL information if any...
             _sslInfo.restoreFrom(reply->attribute(static_cast<QNetworkRequest::Attribute>(KIO::AccessManager::MetaData)), reply->url());
@@ -504,7 +544,7 @@ void WebPage::manageNetworkErrors(QNetworkReply *reply)
         // last chance for the strange things (eg: FTP, custom schemes, etc...)
         if (_protHandler.postHandling(reply->request(), mainFrame()))
             return;
-        
+
     case QNetworkReply::ConnectionRefusedError:              // remote server refused connection
     case QNetworkReply::HostNotFoundError:                   // invalid hostname
     case QNetworkReply::TimeoutError:                        // connection time out
@@ -548,46 +588,104 @@ QString WebPage::errorPage(QNetworkReply *reply)
         return QString("Couldn't open the rekonqinfo.html file");
     }
 
-    QString title = i18n("There was a problem while loading the page");
-
     // NOTE:
     // this, to take care about XSS (see BUG 217464)...
     QString urlString = Qt::escape(reply->url().toString());
 
-    QString iconPath = QString("file://") + KIconLoader::global()->iconPath("dialog-warning" , KIconLoader::Small);
-    iconPath.replace(QL1S("16"), QL1S("128"));
+    // 1. data path
+    QString dataPath = QL1S("file://") + notfoundFilePath;
+    dataPath.remove(QL1S("/htmls/rekonqinfo.html"));
 
+    // 2. title
+    QString title = i18n("There was a problem while loading the page");
+
+    // 3. main content
     QString msg;
+
+    msg += i18n("<h1>Oops! Rekonq cannot load <em>%1</em></h1>", urlString);
+
+
+    msg += i18n("<h2>Wrongly typed?</h2>");
+
     msg += QL1S("<table>");
     msg += QL1S("<tr><td>");
-    msg += QL1S("<img src=\"") + iconPath + QL1S("\" />");
+
+    msg += QL1S("<p>");
+
+    msg += i18n("We tried to load url: %1.<br />", urlString);
+    msg += i18n("Check your address for errors like <em>ww.kde.org</em> instead of <em>www.kde.org</em>.<br />");
+    msg += i18n("If you spelled right, just try to <a href=\"%1\">reload it</a>.<br />", urlString);
+    msg += i18n("Otherwise, just be careful the next time around.");
+
+    msg += QL1S("</p>");
+
+    QString laughIconPath = QString("file://") + KIconLoader::global()->iconPath("face-laugh" , -KIconLoader::SizeHuge, false);
     msg += QL1S("</td><td>");
-    msg += QL1S("<h1>") + reply->errorString() + QL1S("</h1>");
-    msg += QL1S("<h2>") + i18nc("%1=an URL, e.g.'kde.org'", "When connecting to: <b>%1</b>", urlString) + QL1S("</h2>");
+    msg += QL1S("<img src=\"") + laughIconPath + QL1S("\" />");
     msg += QL1S("</td></tr></table>");
 
-    msg += QL1S("<ul><li>") + i18n("Check the address for errors such as <b>ww</b>.kde.org instead of <b>www</b>.kde.org");
-    msg += QL1S("</li><li>") + i18n("If the address is correct, try to check the network connection.") + QL1S("</li><li>") ;
-    msg += i18n("If your computer or network is protected by a firewall or proxy, make sure that rekonq is permitted to access the network.");
-    msg += QL1S("</li><li>") + i18n("Of course, if rekonq does not work properly, you can always say it is a programmer error ;)");
-    msg += QL1S("</li></ul><br/><br/>");
-    msg += QL1S("<input type=\"button\" id=\"reloadButton\" onClick=\"document.location.href='") + urlString + QL1S("';\" value=\"");
-    msg += i18n("Try Again") + QL1S("\" />");
 
-    //Default SearchEngine
+    msg += i18n("<h2>Network problems?</h2>");
+
+    QString faceIconPath = QString("file://") + KIconLoader::global()->iconPath("face-surprise" , -KIconLoader::SizeHuge, false);
+    msg += QL1S("<table>");
+    msg += QL1S("<tr><td width=\"100px\">");
+    msg += QL1S("<img src=\"") + faceIconPath + QL1S("\" />");
+    msg += QL1S("</td><td>");
+
+    msg += QL1S("<p>");
+
+    msg += i18n("Maybe you are having problems with your network.<br />");
+    msg += i18n("Try checking your <a href=\"%1\">network connections</a>", QL1S("about:settings/network"));
+    msg += i18n(", your <a href=\"%1\">proxy settings</a> ", QL1S("about:settings/proxy"));
+    msg += i18n("and your <a href=\"%1\">firewall</a>.<br />", QL1S("about:settings/firewall"));
+    msg += i18n("Then try again.<br />");
+
+    msg += QL1S("</p>");
+
+    msg += QL1S("</td></tr></table>");
+
+
+    msg += i18n("<h2>Suggestions</h2>");
+
+    msg += QL1S("<table>");
+    msg += QL1S("<tr><td>");
+
+    msg += QL1S("<p>");
+
+    // Default SearchEngine
     KService::Ptr defaultEngine = SearchEngine::defaultEngine();
 
     if (defaultEngine)
     {
-        msg += i18n("or");
+        msg += i18n("Consult your default search engine about:");
         msg += QL1S(" <a href=\"") + SearchEngine::buildQuery(defaultEngine, urlString) + QL1S("\">");
-        msg += i18n("Search with %1", defaultEngine->name()) + QL1S("</a>");
+        msg += i18n("search with %1", defaultEngine->name());
+        msg += QL1S("</a>!<br />");
+    }
+    else
+    {
+        msg += i18n("You don't have a default search engine set. We won't suggest you one.");
     }
 
-    QString html = QString(QL1S(file.readAll()))
-                   .arg(title)
-                   .arg(msg)
-                   ;
+    msg += i18n("At least, you can consult a cached snapshot of the site: <br />");
+    msg += i18n("Try checking the <a href=\"%1\">Wayback Machine</a>", QL1S("http://wayback.archive.org/web/*/") + urlString);
+    msg += i18n(" or the <a href=\"%1\">Google Cache</a>.", QL1S("http://google.com/search?q=cache:") + urlString);
+
+    msg += QL1S("</p>");
+
+    QString winkIconPath = QString("file://") + KIconLoader::global()->iconPath("face-wink" , -KIconLoader::SizeHuge, false);
+    msg += QL1S("</td><td>");
+    msg += QL1S("<img src=\"") + winkIconPath + QL1S("\" />");
+    msg += QL1S("</td></tr></table>");
+
+    // done. Replace variables and show it
+    QString html = QL1S(file.readAll());
+
+    html.replace(QL1S("$DEFAULT_PATH"), dataPath);
+    html.replace(QL1S("$PAGE_TITLE"), title);
+    html.replace(QL1S("$MAIN_CONTENT"), msg);
+
     return html;
 }
 
@@ -663,17 +761,17 @@ bool WebPage::hasSslValid() const
     if (certList.isEmpty())
         return false;
 
-    Q_FOREACH(const QSslCertificate & cert, certList)
-    {
-        if (!cert.isValid())
-            return false;
-    }
+    const QSslCertificate cert = certList.at(0);
+    if (!cert.isValid())
+        return false;
 
     QList<QStringList> errorList = SslInfoDialog::errorsFromString(_sslInfo.certificateErrors());
-    Q_FOREACH(const QStringList & list, errorList)
+    if (!errorList.isEmpty())
     {
+        QStringList list = errorList.at(0);
         if (!list.isEmpty())
             return false;
     }
+
     return true;
 }
