@@ -34,6 +34,7 @@
 
 // Local Includes
 #include "application.h"
+#include "adblockmanager.h"
 #include "bookmarkmanager.h"
 #include "iconmanager.h"
 #include "mainview.h"
@@ -53,14 +54,16 @@
 #include <KToolInvocation>
 
 // Qt Includes
-#include <QtCore/QFile>
-#include <QtCore/QTimer>
+#include <QFile>
+#include <QTimer>
 
-#include <QtGui/QClipboard>
-#include <QtGui/QContextMenuEvent>
+#include <QClipboard>
+#include <QContextMenuEvent>
+#include <QLabel>
 
-#include <QtWebKit/QWebFrame>
-#include <QtWebKit/QWebHistory>
+#include <QWebFrame>
+#include <QWebHistory>
+#include <QNetworkRequest>
 
 
 WebView::WebView(QWidget* parent)
@@ -78,15 +81,8 @@ WebView::WebView(QWidget* parent)
     , m_accessKeysPressed(false)
     , m_accessKeysActive(false)
 {
-    // download system
-    connect(this, SIGNAL(linkShiftClicked(KUrl)), page(), SLOT(downloadUrl(KUrl)));
-
-    // middle click || ctrl + click signal
-    connect(this, SIGNAL(linkMiddleOrCtrlClicked(KUrl)), this, SLOT(loadUrlInNewTab(KUrl)));
-
     // loadUrl signal
-    connect(this, SIGNAL(loadUrl(KUrl,Rekonq::OpenType)),
-            rApp, SLOT(loadUrl(KUrl,Rekonq::OpenType)));
+    connect(this, SIGNAL(loadUrl(KUrl, Rekonq::OpenType)), rApp, SLOT(loadUrl(KUrl, Rekonq::OpenType)));
 
     // Auto scroll timer
     connect(m_autoScrollTimer, SIGNAL(timeout()), this, SLOT(scrollFrameChanged()));
@@ -108,6 +104,25 @@ WebView::~WebView()
 }
 
 
+void WebView::load(const QUrl &url)
+{
+    load(QNetworkRequest(url));
+}
+
+
+void WebView::load(const QNetworkRequest &req, QNetworkAccessManager::Operation op, const QByteArray &body)
+{
+    QNetworkRequest request = req;
+    const QUrl &reqUrl = request.url();
+    if (reqUrl.host() == url().host())
+    {
+        request.setRawHeader(QByteArray("Referer"), url().toEncoded());
+    }
+
+    KWebView::load(request, op, body);
+}
+
+
 void WebView::loadStarted()
 {
     hideAccessKeys();
@@ -252,7 +267,15 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
         menu.addAction(a);
 
         menu.addSeparator();
-        menu.addAction(pageAction(KWebPage::DownloadLinkToDisk));
+
+        // Don't show dots if we are NOT going to ask for download path
+        a = pageAction(KWebPage::DownloadLinkToDisk);
+        if (ReKonfig::askDownloadPath())
+            a->setText(i18n("Save Link..."));
+        else
+            a->setText(i18n("Save Link"));
+
+        menu.addAction(a);
         menu.addAction(pageAction(KWebPage::CopyLinkToClipboard));
     }
 
@@ -267,16 +290,24 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
 
         a = new KAction(KIcon("view-preview"), i18n("&View Image"), this);
         a->setData(result.imageUrl());
-        connect(a, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)),
-                this, SLOT(viewImage(Qt::MouseButtons,Qt::KeyboardModifiers)));
+        connect(a, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)),
+                this, SLOT(viewImage(Qt::MouseButtons, Qt::KeyboardModifiers)));
         menu.addAction(a);
 
         menu.addAction(pageAction(KWebPage::DownloadImageToDisk));
 
         a = new KAction(KIcon("view-media-visualization"), i18n("&Copy Image Location"), this);
         a->setData(result.imageUrl());
-        connect(a, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(slotCopyImageLocation()));
+        connect(a, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), this, SLOT(slotCopyImageLocation()));
         menu.addAction(a);
+
+        if (rApp->adblockManager()->isEnabled())
+        {
+            a = new KAction(KIcon("preferences-web-browser-adblock"), i18n("Block image"), this);
+            a->setData(result.imageUrl());
+            connect(a, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), this, SLOT(blockImage()));
+            menu.addAction(a);
+        }
     }
 
     // ACTIONS FOR TEXT SELECTION -----------------------------------------------------
@@ -374,7 +405,7 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
     }
     else
     {
-        a = rApp->bookmarkManager()->actionByName("rekonq_add_bookmark");
+        a = mainwindow->actionByName(KStandardAction::name(KStandardAction::AddBookmark));
         menu.addAction(a);
     }
     menu.addAction(sendByMailAction);
@@ -456,6 +487,7 @@ void WebView::mousePressEvent(QMouseEvent *event)
     default:
         break;
     };
+
     KWebView::mousePressEvent(event);
 }
 
@@ -495,9 +527,9 @@ void WebView::mouseMoveEvent(QMouseEvent *event)
 void WebView::dropEvent(QDropEvent *event)
 {
     bool isEditable = page()->frameAt(event->pos())->hitTestContent(event->pos()).isContentEditable();
-    if (event->mimeData()->hasFormat("application/rekonq-bookmark"))
+    if (event->mimeData()->hasFormat(BookmarkManager::bookmark_mime_type()))
     {
-        QByteArray addresses = event->mimeData()->data("application/rekonq-bookmark");
+        QByteArray addresses = event->mimeData()->data(BookmarkManager::bookmark_mime_type());
         KBookmark bookmark =  rApp->bookmarkManager()->findByAddress(QString::fromLatin1(addresses.data()));
         if (bookmark.isGroup())
         {
@@ -887,12 +919,6 @@ void WebView::inspect()
 }
 
 
-void WebView::loadUrlInNewTab(const KUrl &url)
-{
-    emit loadUrl(url, Rekonq::NewTab);
-}
-
-
 void WebView::scrollFrameChanged()
 {
     // do the scrolling
@@ -1188,8 +1214,60 @@ void WebView::sendByMail()
 {
     KAction *a = qobject_cast<KAction*>(sender());
     QString url = a->data().toString();
-    kDebug() << "URL " << url;
 
     KToolInvocation::invokeMailer("", "", "", "", url);
 }
 
+
+void WebView::blockImage()
+{
+    QAction *action = qobject_cast<QAction*>(sender());
+    if (!action)
+        return;
+
+    QString imageUrl = action->data().toString();
+    rApp->adblockManager()->addCustomRule(imageUrl);
+}
+
+
+void WebView::mouseReleaseEvent(QMouseEvent *event)
+{
+    QWebHitTestResult hitTest = page()->mainFrame()->hitTestContent(event->pos());
+    const QUrl url = hitTest.linkUrl();
+
+    if (!url.isEmpty())
+    {
+        if (event->button() & Qt::MidButton)
+        {
+            if (event->modifiers() & Qt::ShiftModifier)
+            {
+                if (ReKonfig::openNewTabsInBackground())
+                    emit loadUrl(url, Rekonq::NewFocusedTab);
+                else
+                    emit loadUrl(url, Rekonq::NewBackGroundTab);
+                event->accept();
+                return;
+            }
+
+            emit loadUrl(url, Rekonq::NewTab);
+            event->accept();
+            return;
+        }
+
+        if ((event->button() & Qt::LeftButton) && (event->modifiers() & Qt::ControlModifier))
+        {
+            emit loadUrl(url, Rekonq::NewTab);
+            event->accept();
+            return;
+        }
+
+        if ((event->button() & Qt::LeftButton) && (event->modifiers() & Qt::ShiftModifier))
+        {
+            page()->downloadUrl(url);
+            event->accept();
+            return;
+        }
+    }
+
+    QWebView::mouseReleaseEvent(event);
+}
